(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    375260,       9958]
NotebookOptionsPosition[    367213,       9699]
NotebookOutlinePosition[    367807,       9720]
CellTagsIndexPosition[    367764,       9717]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to access FRED\[RegisteredTrademark] data"
}], "Title",
 CellChangeTimes->{{3.4698189390970917`*^9, 3.469818939671599*^9}, {
   3.469893536212487*^9, 3.4698935652397203`*^9}, 3.470140187756591*^9}],

Cell[TextData[{
 "comments and feedback: ",
 ButtonBox["mhoneychurch@wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["mailto:mhoneychurch@wolfram.com?subject=FRED%20package"], None},
  ButtonNote->"mailto:mhoneychurch@wolfram.com"]
}], "Text",
 CellChangeTimes->{{3.477928682174109*^9, 3.47792870133344*^9}}],

Cell["version 1.1", "Text",
 CellChangeTimes->{{3.477929168641223*^9, 3.477929171151554*^9}}],

Cell["1.1 Added FRED package.", "Text",
 CellChangeTimes->{{3.47792917479172*^9, 3.4779291895124187`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.469894301809667*^9, 3.469894303671876*^9}}],

Cell[TextData[{
 "FRED\[RegisteredTrademark], stands for Federal Reserve Economic Data, a \
database of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"20", ",", "318"}], TraditionalForm]]],
 " U.S. economic time series. This is a brief description, with some \
examples, of how to create a function to download FRED\[RegisteredTrademark] \
data. In order to proceed with this example you will need to obtain an API \
key from the Federal Reserve Bank of St Louis. Details on how to obtain an \
API key can be found here: ",
 ButtonBox["http://api.stlouisfed.org/api_key.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://api.stlouisfed.org/api_key.html"], None},
  ButtonNote->"http://api.stlouisfed.org/api_key.html"],
 ". Documentation for the API can be found here: ",
 ButtonBox["http://api.stlouisfed.org/docs/fred",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://api.stlouisfed.org/docs/fred/"], None},
  ButtonNote->"http://api.stlouisfed.org/docs/fred/"],
 ".\n\nThis example focusses is on building a function to retrieve economic \
data series using the information provided here: ",
 ButtonBox["http://api.stlouisfed.org/docs/fred/series_observations.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://api.stlouisfed.org/docs/fred/series_observations.html"], None},
  ButtonNote->
   "http://api.stlouisfed.org/docs/fred/series_observations.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.469893594562457*^9, 3.469893735019278*^9}, {
  3.469893863336631*^9, 3.469893908260882*^9}, {3.469894001179694*^9, 
  3.4698940386917048`*^9}, {3.469894076636271*^9, 3.469894112484069*^9}, {
  3.469894268243031*^9, 3.469894284507101*^9}, {3.469905806205513*^9, 
  3.4699058179412622`*^9}, {3.469966594622335*^9, 3.469966596656122*^9}, {
  3.469967938658515*^9, 3.4699679445418987`*^9}}],

Cell[TextData[{
 "The input in this notebook will not evaluate if you do not have a FRED\
\[RegisteredTrademark] API key. The places where the key needs to be entered \
as a separate string or included in the existing string are marked with this \
message: ",
 StyleBox["INSERTyourFREDkey", "MB",
  FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
  Background->RGBColor[0., 1., 1.]]
}], "Text",
 CellFrame->1,
 CellFrameColor->RGBColor[1, 0, 0],
 CellFrameLabels->{{None, None}, {None, 
    Cell[
     TextData[{"Warning"}], "Subsection"]}},
 CellChangeTimes->{
  3.470140418481852*^9, {3.470140555505722*^9, 3.470140582521781*^9}, {
   3.470140637653244*^9, 3.4701406922382927`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic importing of FRED data", "Section",
 CellChangeTimes->{{3.469894400339295*^9, 3.469894404738142*^9}, {
  3.469894778700313*^9, 3.469894783906795*^9}}],

Cell["\<\
In this example a non seasonaly adjusted set of retail sales data, found \
here, http://research.stlouisfed.org/fred2/series/RSAFSNA, will be imported. \
FRED\[RegisteredTrademark] data series are characterized by a small number of \
letters representing a particular series. The data series is  \"RSAFSNA\". By \
default the data is transmitted in XML format.\
\>", "Text",
 CellChangeTimes->{{3.4698946780805397`*^9, 3.469894701192787*^9}, {
  3.469894734558708*^9, 3.4698947510925827`*^9}, {3.4698947924299917`*^9, 
  3.469894799244199*^9}, {3.46989497768184*^9, 3.4698949946109657`*^9}, {
  3.469967958776976*^9, 3.469968015887752*^9}, {3.469968073698888*^9, 
  3.4699681161145267`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=RSAFSNA&\
observation_start=2000-01-01&observation_end=2009-12-10&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\"", ",", "\"\<XML\>\""}], "]"}], ",", 
   "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.469894445394896*^9, 3.469894531449189*^9}, {
  3.469894572067306*^9, 3.469894582916543*^9}, {3.4698946231647053`*^9, 
  3.469894655836153*^9}, {3.470140253337035*^9, 3.470140258238652*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
      RowBox[{
       RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
       RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
     "}"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observations\"\>", ",", 
      RowBox[{"{", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"236973\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"251181\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-03-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"280154\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-04-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"265005\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-05-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"284306\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\[LeftSkeleton]", "109", "\[RightSkeleton]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "}"}]}], "]"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.4699720468851213`*^9}]
}, Open  ]],

Cell["\<\
To make this more flexible, the strings for the data series, the start date, \
and end date can be entered separately:\
\>", "Text",
 CellChangeTimes->{{3.469894825645256*^9, 3.469894863652495*^9}, 
   3.469895002746365*^9, 3.469966979466258*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"series", "=", "\"\<RSAFSNA\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"startDate", "=", "\"\<2000-01-01\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"endDate", "=", "\"\<2009-12-10\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.469894868364069*^9, 3.469894905743455*^9}, {
   3.469895420419941*^9, 3.469895424283689*^9}, 3.469968157630135*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{
     RowBox[{
     "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\"", 
      "<>", "series", "<>", "\"\<&observation_start=\>\"", "<>", "startDate", 
      "<>", "\"\<&observation_end=\>\"", "<>", "endDate", "<>", 
      "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "\"\<XML\>\""}], "]"}], ",", 
   "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.469894921829814*^9, 3.4698949646608458`*^9}, {
   3.4698954269509068`*^9, 3.46989543066225*^9}, 3.4701403612766457`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
      RowBox[{
       RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
       RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
     "}"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observations\"\>", ",", 
      RowBox[{"{", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"236973\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"251181\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-03-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"280154\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-04-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"265005\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-05-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"284306\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\[LeftSkeleton]", "109", "\[RightSkeleton]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "}"}]}], "]"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972047361945*^9}]
}, Open  ]],

Cell["A simple function can be created from the above input:", "Text",
 CellChangeTimes->{{3.469895375745593*^9, 3.469895386920391*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FRED1", "[", 
   RowBox[{"series_", ",", "startDate_", ",", "endDate_"}], "]"}], ":=", 
  RowBox[{"Import", "[", 
   RowBox[{
    RowBox[{
    "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\"", "<>",
      "series", "<>", "\"\<&observation_start=\>\"", "<>", "startDate", "<>", 
     "\"\<&observation_end=\>\"", "<>", "endDate", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "\"\<XML\>\""}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469895390528104*^9, 3.469895410226576*^9}, 
   3.4698954446227913`*^9, 3.469898250930957*^9, 3.4701403682682867`*^9}],

Cell["\<\
Test this function with another series: TWEXB, a series of weekly trade \
weighted index data.\
\>", "Text",
 CellChangeTimes->{{3.469968172771936*^9, 3.469968204427457*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED1", "[", 
    RowBox[{
    "\"\<TWEXB\>\"", ",", "\"\<2000-01-01\>\"", ",", "\"\<2009-12-10\>\""}], 
    "]"}], ",", "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.469895448502034*^9, 3.469895481836997*^9}, 
   3.4698982550154333`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
      RowBox[{
       RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
       RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
     "}"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observations\"\>", ",", 
      RowBox[{"{", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-05\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.62\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-12\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.95\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-19\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.07\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-26\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.14\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-02\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"116.44\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\[LeftSkeleton]", "509", "\[RightSkeleton]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-11\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.54\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-18\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-25\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-02\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"100.56\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-09\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.01\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "}"}]}], "]"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972047973091*^9}]
}, Open  ]],

Cell["\<\
This is the function to build on to create a flexible FRED\
\[RegisteredTrademark] importing function.\
\>", "Text",
 CellChangeTimes->{{3.46996701185798*^9, 3.4699670377056713`*^9}, {
  3.469968223221367*^9, 3.469968223971883*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Constructing a function to import FRED\[RegisteredTrademark] data\
\>", "Section",
 CellChangeTimes->{{3.469895265911579*^9, 3.469895277901884*^9}, {
  3.469967032268561*^9, 3.469967033929606*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Introducing ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " date list entries as arguments"
}], "Subsection",
 CellChangeTimes->{{3.469895795757114*^9, 3.469895805570017*^9}, {
  3.4699670470201387`*^9, 3.469967049585651*^9}}],

Cell[TextData[{
 "The next thing to do is to make the entry of the start and end dates more \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " like, i.e. use the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " date list format."
}], "Text",
 CellChangeTimes->{{3.4698955352693577`*^9, 3.4698955702605553`*^9}, 
   3.469968262119761*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FRED2", "[", 
   RowBox[{"series_String", ",", "startDate_List", ",", "endDate_List"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"start1", ",", "end1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Import", "[", 
      RowBox[{
       RowBox[{
       "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\"\
", "<>", "series", "<>", "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
        "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "\"\<XML\>\""}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.469895579314489*^9, 3.469895644601282*^9}, {
   3.469895687124147*^9, 3.469895690906453*^9}, {3.469895728149296*^9, 
   3.4698957347562637`*^9}, 3.4698957876872797`*^9, 3.469898265758465*^9, 
   3.4701403781615543`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED2", "[", 
    RowBox[{"\"\<TWEXB\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}]}], "]"}], ",", "20"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.46989566342701*^9, 3.469895674417001*^9}, 
   3.4698957737093687`*^9, {3.469895939576425*^9, 3.469895951441293*^9}, 
   3.469898269223669*^9, {3.4699682834328337`*^9, 3.469968284567137*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
      RowBox[{
       RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
       RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
     "}"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observations\"\>", ",", 
      RowBox[{"{", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-05\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.62\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-12\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.95\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-19\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.07\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-26\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.14\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-02\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"116.44\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"\[LeftSkeleton]", "509", "\[RightSkeleton]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-11\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.54\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-18\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-25\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-02\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"100.56\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", 
        RowBox[{"XMLElement", "[", 
         RowBox[{"\<\"observation\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
            
            RowBox[{"\<\"realtime_start\"\>", 
             "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
            RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}],
             ",", 
            RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-09\"\>"}], ",", 
            RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.01\"\>"}]}], "}"}], 
          ",", 
          RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "}"}]}], "]"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.4699720516704197`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entering a series or list of data series", "Subsection",
 CellChangeTimes->{{3.469895885357421*^9, 3.469895893364049*^9}}],

Cell[TextData[{
 "Suppose you want to retrieve more than one data series? The user could \
enter the desired series as a list and then map that list onto the ",
 ButtonBox["Import",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Import"],
 " function:"
}], "Text",
 CellChangeTimes->{{3.469895901308467*^9, 3.469895932100857*^9}, {
  3.469896054742799*^9, 3.469896086000572*^9}, {3.469969237474058*^9, 
  3.469969237475561*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FRED3", "[", 
   RowBox[{
    RowBox[{"series", ":", 
     RowBox[{"(", 
      RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_List", ",", 
    "endDate_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"start1", ",", "end1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
         RowBox[{
         "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\
\"", "<>", "#", "<>", "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
          "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "\"\<XML\>\""}], "]"}], 
       "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", "series", "}"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469896104173519*^9, 3.469896141111045*^9}, {
   3.46989617944709*^9, 3.469896254361463*^9}, {3.469896377644822*^9, 
   3.4698963788681993`*^9}, 3.469898276087954*^9, 3.470140385994851*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED3", "[", 
    RowBox[{"\"\<TWEXB\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}]}], "]"}], ",", "20"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.46989614879629*^9, 3.469896266720744*^9, 3.4698982796797953`*^9, {
   3.4699683231138353`*^9, 3.469968324223968*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
       RowBox[{
        RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
        RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
      "}"}], ",", 
     RowBox[{"XMLElement", "[", 
      RowBox[{"\<\"observations\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-05\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.62\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-12\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"114.95\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-19\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.07\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-26\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"115.14\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-02\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"116.44\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"\[LeftSkeleton]", "509", "\[RightSkeleton]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-11\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.54\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-18\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-25\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.02\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-02\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"100.56\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-12-09\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"101.01\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", "}"}]}], "]"}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.4699720524670553`*^9}]
}, Open  ]],

Cell["That works, but what about a list of data series?", "Text",
 CellChangeTimes->{{3.469896271565024*^9, 3.4698962825410843`*^9}, {
  3.469968335823913*^9, 3.469968336422269*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED3", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<RSAFSNA\>\"", ",", "\"\<twexb\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}]}], "]"}], ",", "20"}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.46989614879629*^9, 3.469896266720744*^9, {3.469896308721755*^9, 
   3.4698963172565193`*^9}, 3.469898290895158*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
        RowBox[{
         RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
         RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
       "}"}], ",", 
      RowBox[{"XMLElement", "[", 
       RowBox[{"\<\"observations\"\>", ",", 
        RowBox[{"{", 
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-01-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"236973\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-02-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"251181\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-03-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"280154\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-04-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"265005\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2000-05-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"284306\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"\[LeftSkeleton]", "109", "\[RightSkeleton]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}], ",", 
          RowBox[{"XMLElement", "[", 
           RowBox[{"\<\"observation\"\>", ",", 
            RowBox[{"{", 
             RowBox[{
              
              RowBox[{"\<\"realtime_start\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              
              RowBox[{"\<\"realtime_end\"\>", 
               "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
              RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
              
              RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}],
             ",", 
            RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.4699720538079367`*^9}]
}, Open  ]],

Cell["Note that the series string is not case sensitive.", "Text",
 CellChangeTimes->{{3.4698964047934303`*^9, 3.469896417592228*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Handling FRED\[RegisteredTrademark] API parameters", "Subsection",
 CellChangeTimes->{{3.469896451491664*^9, 3.469896459441079*^9}, {
  3.469896530893353*^9, 3.4698965348993063`*^9}, {3.469896597415914*^9, 
  3.469896599117385*^9}}],

Cell[TextData[{
 "Additional parameters can be added which form part of a query string in the \
FRED\[RegisteredTrademark] API URL. These API parameters are documented here: \
",
 ButtonBox["http://api.stlouisfed.org/docs/fred/series_observations.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://api.stlouisfed.org/docs/fred/series_observations.html"], None},
  ButtonNote->
   "http://api.stlouisfed.org/docs/fred/series_observations.html"],
 ". This example will focus on three parameters, units, output type, and file \
type."
}], "Text",
 CellChangeTimes->{{3.469896537882917*^9, 3.4698965712920322`*^9}, {
  3.4698966877051573`*^9, 3.469896780969576*^9}, {3.469897531149973*^9, 
  3.469897536571095*^9}, {3.4699683643456383`*^9, 3.469968365575427*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<Unit\>\"", ",", "\"\<Transformation\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<lin\>\"", ",", "\"\<No transformation (default) \>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<chg\>\"", ",", "\"\<Change\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<ch1\>\"", ",", "\"\<Change from Year Ago\>\""}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"\"\<pch\>\"", ",", "\"\<Percent Change\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<pc1\>\"", ",", "\"\<Percent Change from Year Ago\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<pca\>\"", ",", "\"\<Compounded Annual Rate of Change\>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<cch\>\"", ",", 
        "\"\<Continuously Compounded Rate of Change \>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<cca\>\"", ",", 
        "\"\<Continuously Compounded Annual Rate of Change\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<log\>\"", ",", "\"\<Natural Log\>\""}], "}"}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Text", "@", 
  RowBox[{"Grid", "[", 
   RowBox[{"data", ",", "\[IndentingNewLine]", 
    RowBox[{"Background", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", ".9"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Lighter", "[", 
            RowBox[{
             RowBox[{"Blend", "[", 
              RowBox[{"{", 
               RowBox[{"Brown", ",", "Gray"}], "}"}], "]"}], ",", ".9"}], 
            "]"}]}], "}"}]}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Dividers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"False", ",", 
         RowBox[{"{", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", ".5"}], "]"}], "}"}], ",", "False"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"{", "False", "}"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Alignment", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Center"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"ItemSize", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"Darker", "[", 
      RowBox[{"Gray", ",", ".6"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"ItemStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}], ",", 
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}]}], "}"}], ",", 
       "None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", " ", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.467993272868681*^9, 3.467993277266911*^9}, 
   3.467993334934256*^9, {3.467993391877067*^9, 3.467993425781692*^9}, 
   3.467998838375548*^9, {3.4679995799317408`*^9, 3.467999581439996*^9}, 
   3.467999657117723*^9, 3.467999724308467*^9, {3.4679998469274387`*^9, 
   3.46799986559373*^9}, {3.467999902580778*^9, 3.4679999323411818`*^9}, {
   3.4680000051414757`*^9, 3.468000031264039*^9}, {3.468000066201365*^9, 
   3.468000096189866*^9}, {3.468000181649374*^9, 3.468000207306588*^9}, {
   3.4680003105100613`*^9, 3.468000336183278*^9}, {3.46989708361167*^9, 
   3.46989717735638*^9}, {3.4698974317108994`*^9, 3.469897447886271*^9}}],

Cell[BoxData[
 InterpretationBox[Cell[BoxData[
   TagBox[GridBox[{
      {"\<\"Unit\"\>", "\<\"Transformation\"\>"},
      {"\<\"lin\"\>", "\<\"No transformation (default) \"\>"},
      {"\<\"chg\"\>", "\<\"Change\"\>"},
      {"\<\"ch1\"\>", "\<\"Change from Year Ago\"\>"},
      {"\<\"pch\"\>", "\<\"Percent Change\"\>"},
      {"\<\"pc1\"\>", "\<\"Percent Change from Year Ago\"\>"},
      {"\<\"pca\"\>", "\<\"Compounded Annual Rate of Change\"\>"},
      {"\<\"cch\"\>", "\<\"Continuously Compounded Rate of Change \"\>"},
      {"\<\"cca\"\>", "\<\"Continuously Compounded Annual Rate of Change\"\>"},
      {"\<\"log\"\>", "\<\"Natural Log\"\>"}
     },
     AutoDelete->False,
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Center}}},
     GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
         RGBColor[0.95, 0.95, 0.95], {
          GrayLevel[1], 
          RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}},
     GridBoxDividers->{"Columns" -> {False, {
          RGBColor[0.75, 0.75, 0.75]}, False}, "Rows" -> {
         RGBColor[0.35, 0.35, 0.35], 
         RGBColor[0.35, 0.35, 0.35], {False}, 
         RGBColor[0.35, 0.35, 0.35]}},
     GridBoxFrame->{
      "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> RGBColor[0.2, 0.2, 0.2]}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxItemStyle->{"Columns" -> {
         Directive["Table"], 
         Directive["Table"]}, "Rows" -> {{None}}, 
       "ItemsIndexed" -> {{1, 2} -> Directive[12, Bold], {1, 1} -> 
         Directive[12, Bold]}},
     GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
    "Grid"]], "Text", "TR"],
  Text[
   Grid[{{"Unit", "Transformation"}, {
     "lin", "No transformation (default) "}, {"chg", "Change"}, {
     "ch1", "Change from Year Ago"}, {"pch", "Percent Change"}, {
     "pc1", "Percent Change from Year Ago"}, {
     "pca", "Compounded Annual Rate of Change"}, {
     "cch", "Continuously Compounded Rate of Change "}, {
     "cca", "Continuously Compounded Annual Rate of Change"}, {
     "log", "Natural Log"}}, Background -> {None, {
       RGBColor[0.95, 0.95, 0.95], {
        GrayLevel[1], 
        RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}}, 
    Dividers -> {{False, {
        RGBColor[0.75, 0.75, 0.75]}, False}, {
       RGBColor[0.35, 0.35, 0.35], 
       RGBColor[0.35, 0.35, 0.35], {False}, 
       RGBColor[0.35, 0.35, 0.35]}}, Alignment -> {Left, Center}, ItemSize -> 
    Automatic, Frame -> RGBColor[0.2, 0.2, 0.2], ItemStyle -> {{
       Directive["Table"], 
       Directive["Table"]}, 
      None, {{1, 2} -> Directive[12, Bold], {1, 1} -> Directive[12, Bold]}}, 
    Spacings -> {1, 1}]]]], "Output",
 CellChangeTimes->{3.469972053995331*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<Output type\>\"", ",", "\"\<Value\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<1\>\"", ",", 
        "\"\<Observations by Real-Time Period (default)\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<2\>\"", ",", 
        "\"\<Observations by Vintage Date, All Observations\>\""}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<3\>\"", ",", 
        "\"\<Observations by Vintage Date, New and Revised Observations \
Only\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<4\>\"", ",", "\"\<Observations,Initial Release Only\>\""}], 
       "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Text", "@", 
  RowBox[{"Grid", "[", 
   RowBox[{"data", ",", "\[IndentingNewLine]", 
    RowBox[{"Background", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", ".9"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Lighter", "[", 
            RowBox[{
             RowBox[{"Blend", "[", 
              RowBox[{"{", 
               RowBox[{"Brown", ",", "Gray"}], "}"}], "]"}], ",", ".9"}], 
            "]"}]}], "}"}]}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Dividers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"False", ",", 
         RowBox[{"{", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", ".5"}], "]"}], "}"}], ",", "False"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"{", "False", "}"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Alignment", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Center", ",", "Left"}], "}"}], ",", "Center"}], "}"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"ItemSize", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"Darker", "[", 
      RowBox[{"Gray", ",", ".6"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"ItemStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}], ",", 
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}]}], "}"}], ",", 
       "None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", " ", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.467993272868681*^9, 3.467993277266911*^9}, 
   3.467993334934256*^9, {3.467993391877067*^9, 3.467993425781692*^9}, 
   3.467998838375548*^9, {3.4679995799317408`*^9, 3.467999581439996*^9}, 
   3.467999657117723*^9, 3.467999724308467*^9, {3.4679998469274387`*^9, 
   3.46799986559373*^9}, {3.467999902580778*^9, 3.4679999323411818`*^9}, {
   3.4680000051414757`*^9, 3.468000031264039*^9}, {3.468000066201365*^9, 
   3.468000096189866*^9}, {3.468000181649374*^9, 3.468000207306588*^9}, {
   3.4680003105100613`*^9, 3.468000336183278*^9}, {3.46989708361167*^9, 
   3.46989717735638*^9}, {3.4698972822902527`*^9, 3.46989733967898*^9}, {
   3.469897464731358*^9, 3.469897467496916*^9}}],

Cell[BoxData[
 InterpretationBox[Cell[BoxData[
   TagBox[GridBox[{
      {"\<\"Output type\"\>", "\<\"Value\"\>"},
      {"\<\"1\"\>", "\<\"Observations by Real-Time Period (default)\"\>"},
      {"\<\"2\"\>", "\<\"Observations by Vintage Date, All \
Observations\"\>"},
      {"\<\"3\"\>", "\<\"Observations by Vintage Date, New and Revised \
Observations Only\"\>"},
      {"\<\"4\"\>", "\<\"Observations,Initial Release Only\"\>"}
     },
     AutoDelete->False,
     GridBoxAlignment->{"Columns" -> {Center, Left}, "Rows" -> {{Center}}},
     GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
         RGBColor[0.95, 0.95, 0.95], {
          GrayLevel[1], 
          RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}},
     GridBoxDividers->{"Columns" -> {False, {
          RGBColor[0.75, 0.75, 0.75]}, False}, "Rows" -> {
         RGBColor[0.35, 0.35, 0.35], 
         RGBColor[0.35, 0.35, 0.35], {False}, 
         RGBColor[0.35, 0.35, 0.35]}},
     GridBoxFrame->{
      "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> RGBColor[0.2, 0.2, 0.2]}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxItemStyle->{"Columns" -> {
         Directive["Table"], 
         Directive["Table"]}, "Rows" -> {{None}}, 
       "ItemsIndexed" -> {{1, 2} -> Directive[12, Bold], {1, 1} -> 
         Directive[12, Bold]}},
     GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
    "Grid"]], "Text", "TR"],
  Text[
   Grid[{{"Output type", "Value"}, {
     "1", "Observations by Real-Time Period (default)"}, {
     "2", "Observations by Vintage Date, All Observations"}, {
     "3", "Observations by Vintage Date, New and Revised Observations Only"}, \
{"4", "Observations,Initial Release Only"}}, Background -> {None, {
       RGBColor[0.95, 0.95, 0.95], {
        GrayLevel[1], 
        RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}}, 
    Dividers -> {{False, {
        RGBColor[0.75, 0.75, 0.75]}, False}, {
       RGBColor[0.35, 0.35, 0.35], 
       RGBColor[0.35, 0.35, 0.35], {False}, 
       RGBColor[0.35, 0.35, 0.35]}}, Alignment -> {{Center, Left}, Center}, 
    ItemSize -> Automatic, Frame -> RGBColor[0.2, 0.2, 0.2], ItemStyle -> {{
       Directive["Table"], 
       Directive["Table"]}, 
      None, {{1, 2} -> Directive[12, Bold], {1, 1} -> Directive[12, Bold]}}, 
    Spacings -> {1, 1}]]]], "Output",
 CellChangeTimes->{3.469972054057212*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<File type\>\"", ",", "\"\<Type\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<xml \>\"", ",", 
        "\"\< Extensible Markup Language XML (default)\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<txt \>\"", ",", "\"\< Tab delimited Text\>\""}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"\"\<xls \>\"", ",", "\"\< Excel Spreadsheet\>\""}], "}"}]}], 
     "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Text", "@", 
  RowBox[{"Grid", "[", 
   RowBox[{"data", ",", "\[IndentingNewLine]", 
    RowBox[{"Background", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lighter", "[", 
          RowBox[{"Gray", ",", ".9"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Lighter", "[", 
            RowBox[{
             RowBox[{"Blend", "[", 
              RowBox[{"{", 
               RowBox[{"Brown", ",", "Gray"}], "}"}], "]"}], ",", ".9"}], 
            "]"}]}], "}"}]}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Dividers", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"False", ",", 
         RowBox[{"{", 
          RowBox[{"Lighter", "[", 
           RowBox[{"Gray", ",", ".5"}], "]"}], "}"}], ",", "False"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}], ",", 
         RowBox[{"{", "False", "}"}], ",", 
         RowBox[{"Darker", "[", 
          RowBox[{"Gray", ",", ".3"}], "]"}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Alignment", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Center", ",", "Left"}], "}"}], ",", "Center"}], "}"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"ItemSize", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"Darker", "[", 
      RowBox[{"Gray", ",", ".6"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"ItemStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}], ",", 
         RowBox[{"Directive", "[", "\"\<Table\>\"", "]"}]}], "}"}], ",", 
       "None", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", " ", 
          RowBox[{"Directive", "[", 
           RowBox[{"12", ",", "Bold"}], "]"}]}]}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.467993272868681*^9, 3.467993277266911*^9}, 
   3.467993334934256*^9, {3.467993391877067*^9, 3.467993425781692*^9}, 
   3.467998838375548*^9, {3.4679995799317408`*^9, 3.467999581439996*^9}, 
   3.467999657117723*^9, 3.467999724308467*^9, {3.4679998469274387`*^9, 
   3.46799986559373*^9}, {3.467999902580778*^9, 3.4679999323411818`*^9}, {
   3.4680000051414757`*^9, 3.468000031264039*^9}, {3.468000066201365*^9, 
   3.468000096189866*^9}, {3.468000181649374*^9, 3.468000207306588*^9}, {
   3.4680003105100613`*^9, 3.468000336183278*^9}, {3.46989708361167*^9, 
   3.46989717735638*^9}, {3.4698972822902527`*^9, 3.46989733967898*^9}, {
   3.46989737477675*^9, 3.469897412999586*^9}, {3.469897491482358*^9, 
   3.469897504671714*^9}, {3.4698994742970457`*^9, 3.4698995019845057`*^9}, {
   3.469899930275985*^9, 3.469899930584251*^9}}],

Cell[BoxData[
 InterpretationBox[Cell[BoxData[
   TagBox[GridBox[{
      {"\<\"File type\"\>", "\<\"Type\"\>"},
      {"\<\"xml \"\>", "\<\" Extensible Markup Language XML (default)\"\>"},
      {"\<\"txt \"\>", "\<\" Tab delimited Text\"\>"},
      {"\<\"xls \"\>", "\<\" Excel Spreadsheet\"\>"}
     },
     AutoDelete->False,
     GridBoxAlignment->{"Columns" -> {Center, Left}, "Rows" -> {{Center}}},
     GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
         RGBColor[0.95, 0.95, 0.95], {
          GrayLevel[1], 
          RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}},
     GridBoxDividers->{"Columns" -> {False, {
          RGBColor[0.75, 0.75, 0.75]}, False}, "Rows" -> {
         RGBColor[0.35, 0.35, 0.35], 
         RGBColor[0.35, 0.35, 0.35], {False}, 
         RGBColor[0.35, 0.35, 0.35]}},
     GridBoxFrame->{
      "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> RGBColor[0.2, 0.2, 0.2]}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxItemStyle->{"Columns" -> {
         Directive["Table"], 
         Directive["Table"]}, "Rows" -> {{None}}, 
       "ItemsIndexed" -> {{1, 2} -> Directive[12, Bold], {1, 1} -> 
         Directive[12, Bold]}},
     GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
    "Grid"]], "Text", "TR"],
  Text[
   Grid[{{"File type", "Type"}, {
     "xml ", " Extensible Markup Language XML (default)"}, {
     "txt ", " Tab delimited Text"}, {"xls ", " Excel Spreadsheet"}}, 
    Background -> {None, {
       RGBColor[0.95, 0.95, 0.95], {
        GrayLevel[1], 
        RGBColor[0.9550000000000001, 0.9450000000000001, 0.935]}}}, 
    Dividers -> {{False, {
        RGBColor[0.75, 0.75, 0.75]}, False}, {
       RGBColor[0.35, 0.35, 0.35], 
       RGBColor[0.35, 0.35, 0.35], {False}, 
       RGBColor[0.35, 0.35, 0.35]}}, Alignment -> {{Center, Left}, Center}, 
    ItemSize -> Automatic, Frame -> RGBColor[0.2, 0.2, 0.2], ItemStyle -> {{
       Directive["Table"], 
       Directive["Table"]}, 
      None, {{1, 2} -> Directive[12, Bold], {1, 1} -> Directive[12, Bold]}}, 
    Spacings -> {1, 1}]]]], "Output",
 CellChangeTimes->{3.469972054124053*^9}]
}, {2}]],

Cell[TextData[{
 "The parameters are entered as a query string in the URL so will have the \
final form: \"http://\[Ellipsis] &units=lin&output_type=1&file_type=xml& \
\[Ellipsis]\" Options to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions are entered as rules, so in order to follow that convention \
these additional parameters should be entered as rules and then converted to \
a query string. For example options would be entered as:"
}], "Text",
 CellChangeTimes->{{3.469897577534917*^9, 3.469897744991304*^9}, {
  3.469897813251561*^9, 3.4698978194890137`*^9}, {3.469967119718378*^9, 
  3.469967156636228*^9}, {3.469968407555326*^9, 3.4699684078085546`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<lin\>\""}], ",", 
  RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<1\>\""}], ",", 
  RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.4698977563148603`*^9, 3.469897757233839*^9}}],

Cell["and would be transformed to:", "Text",
 CellChangeTimes->{{3.469897760935691*^9, 3.469897764775518*^9}, {
   3.46989782212122*^9, 3.469897822552956*^9}, 3.469967163174206*^9}],

Cell[BoxData["\"\<units=lin&output_type=1&file_type=xml&\>\""], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.469897777299788*^9, 3.469897796977893*^9}}],

Cell["\<\
This can be accomplished by taking a list of the options (parameters), and in \
the initial step, use a rule replacement to convert the list of option rules \
to a list with each element having the form \"option=value\":\
\>", "Text",
 CellChangeTimes->{{3.469897903980342*^9, 3.4698979663026114`*^9}, {
   3.469898029456471*^9, 3.469898051846691*^9}, 3.469905850554422*^9, 
   3.469968433344915*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"parameters", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<lin\>\""}], ",", 
     RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<1\>\""}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4698979757880373`*^9, 3.469897995872217*^9}, {
  3.469903628522732*^9, 3.4699036347674417`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{"parameters", "/.", 
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"x_String", ",", "y_String"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"StringJoin", "@@", 
     RowBox[{"List", "[", 
      RowBox[{"x", ",", "\"\<=\>\"", ",", "y"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.469898010945525*^9, 3.469898014216062*^9}, {
  3.469898075716387*^9, 3.469898076777364*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"units=lin\"\>", ",", "\<\"output_type=1\"\>", 
   ",", "\<\"file_type=xml\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.4699720542031927`*^9}]
}, Open  ]],

Cell[TextData[{
 "The ampersand can be added using ",
 ButtonBox["Riffle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Riffle"],
 ":"
}], "Text",
 CellChangeTimes->{{3.469898093136801*^9, 3.4698981066156387`*^9}, {
  3.469969576786121*^9, 3.4699695767877007`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Riffle", "[", 
  RowBox[{"tmp", ",", "\"\<&\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"units=lin\"\>", ",", "\<\"&\"\>", ",", "\<\"output_type=1\"\>",
    ",", "\<\"&\"\>", ",", "\<\"file_type=xml\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.469972054255082*^9}]
}, Open  ]],

Cell[TextData[{
 "The strings need to be lower case which can be done by mapping the list \
onto ",
 ButtonBox["ToLowerCase",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ToLowerCase"],
 ":"
}], "Text",
 CellChangeTimes->{{3.469898126217326*^9, 3.469898183801484*^9}, {
  3.469900099679696*^9, 3.46990016853563*^9}, {3.469967499942577*^9, 
  3.469967519878297*^9}, {3.469969607189636*^9, 3.469969636862718*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToLowerCase", "/@", 
  RowBox[{"{", 
   RowBox[{
   "\"\<units=lin\>\"", ",", "\"\<&\>\"", ",", "\"\<output_type=1\>\"", ",", 
    "\"\<&\>\"", ",", "\"\<file_type=xMl\>\""}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4699000725782623`*^9, 3.4699000822878437`*^9}, {
  3.469900190540855*^9, 3.469900196628325*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"units=lin\"\>", ",", "\<\"&\"\>", ",", "\<\"output_type=1\"\>",
    ",", "\<\"&\"\>", ",", "\<\"file_type=xml\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.469972054323551*^9}]
}, Open  ]],

Cell["\<\
The string elements can then be joined to form the query string. It is best \
to make a function to perform this task:\
\>", "Text",
 CellChangeTimes->{{3.469898126217326*^9, 3.469898183801484*^9}, {
  3.469900099679696*^9, 3.4699001629930077`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeQueryString", "[", "rules_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tmp", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp", "=", 
      RowBox[{"rules", "/.", 
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"x_String", ",", "y_String"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"StringJoin", "@@", 
         RowBox[{"List", "[", 
          RowBox[{"x", ",", "\"\<=\>\"", ",", "y"}], "]"}]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"StringJoin", "@@", 
      RowBox[{"(", 
       RowBox[{"ToLowerCase", "/@", 
        RowBox[{"Riffle", "[", 
         RowBox[{"tmp", ",", "\"\<&\>\""}], "]"}]}], ")"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.469881487915814*^9, 3.469881547399946*^9}, {
  3.469898165421979*^9, 3.46989816629364*^9}, {3.469900180590592*^9, 
  3.4699001838125668`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeQueryString", "[", "parameters", "]"}]], "Input",
 CellChangeTimes->{{3.469904234128652*^9, 3.469904242774434*^9}}],

Cell[BoxData["\<\"units=lin&output_type=1&file_type=xml\"\>"], "Output",
 CellChangeTimes->{3.469972054417082*^9}]
}, Open  ]],

Cell[TextData[{
 "To incorporate this code into a revised ",
 StyleBox["FRED", "MB"],
 " function, first set the options for the ",
 StyleBox["FRED", "MB"],
 " function:"
}], "Text",
 CellChangeTimes->{{3.469898337695908*^9, 3.469898391854671*^9}, {
  3.469967547071671*^9, 3.469967552647407*^9}, {3.469968480291234*^9, 
  3.469968486443325*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "FRED4", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<lin\>\""}], ",", 
     RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<1\>\""}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 ButtonBox["OptionsPattern[]",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/OptionsPattern"],
 " allows the function to accept options and then use the function ",
 ButtonBox["OptionsValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/OptionValue"],
 " within the function to access the value of the options."
}], "Text",
 CellChangeTimes->{{3.469898501698353*^9, 3.469898602675603*^9}, {
  3.4699675735976067`*^9, 3.469967574869544*^9}, {3.469969073337913*^9, 
  3.469969143707839*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FRED4", "[", 
   RowBox[{
    RowBox[{"series", ":", 
     RowBox[{"(", 
      RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_List", ",", 
    "endDate_List", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"start1", ",", "end1"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
         RowBox[{
         "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\
\"", "<>", "#", "<>", "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
          "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "\"\<XML\>\""}], "]"}], 
       "&"}], "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", "series", "}"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469896104173519*^9, 3.469896141111045*^9}, {
   3.46989617944709*^9, 3.469896254361463*^9}, {3.469896377644822*^9, 
   3.4698963788681993`*^9}, 3.469898276087954*^9, {3.469898443709261*^9, 
   3.469898460708613*^9}, 3.470140411500609*^9}],

Cell[TextData[{
 "Internally within the function, it is best to work with a ",
 StyleBox["list",
  FontSlant->"Italic"],
 " of option rules. Therefore a local variable is created to hold the options \
as a list which can be processed by ",
 StyleBox["makeQueryString", "MB"],
 ". The other important thing is that the file type parameter (option) \
effects the second argument to ",
 StyleBox["Import", "MB"],
 ". For example, for the option ",
 StyleBox["\"file_type\"\[Rule]\"xml\"", "MB"],
 " the import command should read ",
 StyleBox["Import[\"", "MB"],
 StyleBox["URL", "MB",
  FontSlant->"Italic"],
 StyleBox["\",\"XML\"]", "MB"],
 ". However if either of the other two options are entered the data is \
delivered as a zipped file. Therefore if the ",
 StyleBox["\"txt\"", "MB"],
 " or ",
 StyleBox["\"xls\"", "MB"],
 " values are entered for the ",
 StyleBox["\"file_type\"", "MB"],
 " option the import step should read ",
 StyleBox["Import[\"URL\", \"*\"]", "MB"],
 ". So in this next version of the ",
 StyleBox["FRED", "MB"],
 " function the option value for the ",
 StyleBox["\"file_type\"", "MB"],
 " option needs to be tested and the result determines the second argument to \
",
 StyleBox["Import", "MB"],
 ". Note that the ",
 StyleBox["\"file_type\"", "MB"],
 " option value seems to be case sensitive."
}], "Text",
 CellChangeTimes->{{3.469898701366898*^9, 3.469898767438981*^9}, {
  3.469898816188596*^9, 3.4698988655868187`*^9}, {3.469898898498404*^9, 
  3.469899163696268*^9}, {3.469899259565776*^9, 3.469899278803062*^9}, {
  3.469899677256001*^9, 3.4698996981415443`*^9}, {3.4698997415760593`*^9, 
  3.4698997870475903`*^9}, {3.4698999091490593`*^9, 3.469899922650642*^9}, {
  3.4699000013026953`*^9, 3.469900004180395*^9}, {3.469967773964966*^9, 
  3.469967794011125*^9}, {3.4699678629432163`*^9, 3.469967880666314*^9}, {
  3.469969671239745*^9, 3.469969705790311*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "FRED4", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FRED4", "[", 
   RowBox[{
    RowBox[{"series", ":", 
     RowBox[{"(", 
      RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_", ",", 
    "endDate_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "start1", ",", "end1", ",", "opts1", ",", "queryString", ",", "fileType",
       ",", "extension"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"collect", " ", "options"}], " ", "*)"}], "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"opts1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<units\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<units\>\"", "]"}]}], ",", 
        RowBox[{"\"\<output_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<output_type\>\"", "]"}]}], ",", 
        RowBox[{"\"\<file_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], "}"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "date", " ", "strings"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "query", " ", "string", " ", "insert"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"queryString", "=", 
      RowBox[{"makeQueryString", "[", "opts1", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "determine", " ", "second", " ", "argument", " ", "for", " ", 
       "Import"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fileType", "=", 
      RowBox[{"ToLowerCase", "@", 
       RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"extension", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "fileType", ",", "\"\<xml\>\"", ",", "\"\<XML\>\"", ",", "\"\<xls\>\"",
         ",", "\"\<*\>\"", ",", "\"\<txt\>\"", ",", "\"\<*\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
         RowBox[{
         "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\
\"", "<>", 
          RowBox[{"ToString", "[", "#", "]"}], "<>", 
          "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
          "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&\>\"", "<>", 
          "queryString", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "extension"}], "]"}], "&"}], 
      "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", "series", "}"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.466015991030652*^9, 3.466016032564374*^9}, {
   3.466016139573862*^9, 3.466016141507875*^9}, {3.466016225001635*^9, 
   3.4660162538892927`*^9}, 3.466016336130364*^9, 3.466016489597485*^9, {
   3.466016541311713*^9, 3.466016541620955*^9}, 3.466016652146227*^9, {
   3.466016691086628*^9, 3.466016725243649*^9}, {3.466016917507864*^9, 
   3.46601694496313*^9}, {3.466016993944916*^9, 3.4660169949167337`*^9}, {
   3.4660175359102983`*^9, 3.4660175410410852`*^9}, {3.4698089330911703`*^9, 
   3.4698089935073767`*^9}, {3.469809325244069*^9, 3.4698094289006767`*^9}, {
   3.4698188781505823`*^9, 3.4698188971181383`*^9}, {3.469819722218762*^9, 
   3.4698197368973913`*^9}, {3.4698198624750767`*^9, 3.469819868514059*^9}, {
   3.469820228619958*^9, 3.469820260620138*^9}, {3.4698203018703117`*^9, 
   3.469820304452364*^9}, {3.469821256669025*^9, 3.4698212707624607`*^9}, {
   3.469821470599915*^9, 3.469821508368984*^9}, {3.4698220790002613`*^9, 
   3.469822089726617*^9}, {3.469822152873584*^9, 3.4698221608092527`*^9}, {
   3.469822214483282*^9, 3.4698222420378027`*^9}, {3.4698222885848513`*^9, 
   3.4698223790205927`*^9}, {3.469881410297741*^9, 3.4698814464513807`*^9}, {
   3.4698815885450897`*^9, 3.4698816594636507`*^9}, {3.46988193111939*^9, 
   3.4698819565702887`*^9}, {3.469881996993034*^9, 3.469882068731903*^9}, {
   3.4698820994778976`*^9, 3.469882133117625*^9}, 3.4698824347125273`*^9, {
   3.4698824727529707`*^9, 3.469882512291389*^9}, {3.4698825551230717`*^9, 
   3.469882558700638*^9}, {3.4698826809276953`*^9, 3.4698826831334257`*^9}, {
   3.469882789082679*^9, 3.46988281516654*^9}, 3.4698828822658863`*^9, {
   3.4698844710805283`*^9, 3.4698844723168364`*^9}, {3.469884617837785*^9, 
   3.4698846212920847`*^9}, {3.469885122154298*^9, 3.469885129072653*^9}, {
   3.46988776822069*^9, 3.469887768564498*^9}, {3.469887893158313*^9, 
   3.469887893477867*^9}, {3.46989661627166*^9, 3.46989661983704*^9}, {
   3.469896726250222*^9, 3.469896726773631*^9}, {3.469898312778471*^9, 
   3.46989831509131*^9}, {3.469898378775655*^9, 3.4698983962987022`*^9}, {
   3.469898762705505*^9, 3.469898799822164*^9}, 3.469899214607335*^9, 
   3.4698992556719313`*^9, {3.4698993150610847`*^9, 3.469899320032398*^9}, {
   3.469899443332966*^9, 3.469899448202669*^9}, {3.469899809660198*^9, 
   3.469899832611311*^9}, {3.469899899024125*^9, 3.4698998992362843`*^9}, {
   3.469900259231855*^9, 3.46990027815175*^9}, {3.4699003139697313`*^9, 
   3.46990037482163*^9}, {3.469902753023553*^9, 3.4699027591429663`*^9}, {
   3.4699677117392387`*^9, 3.4699677208081284`*^9}, {3.469969867088393*^9, 
   3.469969867470496*^9}, {3.469971999401134*^9, 3.469972005031682*^9}, 
   3.470140442200451*^9}],

Cell["\<\
Thus function can be tested by calling XML, text and Excel formatted data \
from FRED\[RegisteredTrademark].\
\>", "Text",
 CellChangeTimes->{{3.469900496678832*^9, 3.4699005291515617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED4", "[", 
    RowBox[{
     RowBox[{"{", "\"\<RSAFSNA\>\"", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<Xml\>\""}]}], "]"}], ",", 
   "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.46989922415659*^9, 3.469899241199243*^9}, 
   3.4698993276630983`*^9, 3.469899457164412*^9, {3.4698997926762257`*^9, 
   3.469899793442429*^9}, 3.469899861868924*^9, {3.4699000247699547`*^9, 
   3.469900026670735*^9}, {3.469900434330666*^9, 3.4699004420006933`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
       RowBox[{
        RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
        RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
      "}"}], ",", 
     RowBox[{"XMLElement", "[", 
      RowBox[{"\<\"observations\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-01-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"175708\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-02-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"172518\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-03-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"201710\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-04-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"196468\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-05-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"210945\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"\[LeftSkeleton]", "169", "\[RightSkeleton]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", "}"}]}], "]"}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972054986462*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED4", "[", 
    RowBox[{
     RowBox[{"{", "\"\<RSAFSNA\>\"", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<txt\>\""}]}], "]"}], ",", 
   "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.46990045877066*^9, 3.469900459920796*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\<\"Series ID: RSAFSNA\\nLink: \
http://alfred.stlouisfed.org/series?seid=RSAFSNA\\nHelp: \
http://alfred.stlouisfed.org/help\\n\\nALFRED (ArchivaL Federal Reserve \
Economic Data)\\nEconomic Research Division\\nFederal Reserve Bank of St. \
Louis\\n\\nOutput Format: Observations by Real-Time Period\\nFile Created: \
2009-12-16 11:07 AM CST\\n\\n                                                 \
                            Real-Time Period     \\nTitle                     \
                                                  Start         End     \
\\n---------------------------------------------------------------------------\
-----------------------\\nRetail and Food Services Sales                      \
                      2009-12-\"\>", 
      "\[Ellipsis]", "\<\"12-16   2009-12-16 \
\\n\\nUnits\\n----------------------------------------------------------------\
----------------------------------\\nMillions of Dollars                      \
                                 2009-12-16   2009-12-16 \
\\n\\nFrequency\\n------------------------------------------------------------\
--------------------------------------\\nMonthly                              \
                                     2009-12-16   2009-12-16 \\n\\nSeasonal \
Adjustment\\n-----------------------------------------------------------------\
---------------------------------\\nNot Seasonally Adjusted                   \
                                2009-12-16   2009-12-16 \\n\\n\\nVintage \
Dates Specified:\\n\\n2009-12-16\"\>"}], ",", 
     RowBox[{"\<\"\"\>", "\[Ellipsis]", "\<\"\"\>"}]}], "}"}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972058734624*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"FRED4", "[", 
    RowBox[{
     RowBox[{"{", "\"\<RSAFSNA\>\"", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], "]"}], ",", 
   "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.4699004801470823`*^9, 3.469900480729129*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"Series ID: RSAFSNA\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Link: \
http://alfred.stlouisfed.org/series?seid=RSAFSNA\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Help: http://alfred.stlouisfed.org/help\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"ALFRED (ArchivaL Federal Reserve Economic Data)\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Economic Research Division\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Federal Reserve Bank of St. Louis\"\>", ",", "\<\"\"\>",
           ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Output Format: Observations by Real-Time Period\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"File Created: 2009-12-16 11:07 AM CST\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"Real-Time\"\>", 
          ",", "\<\" Period\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Title:\"\>", ",", "\<\"Start\"\>", ",", "\<\"End\"\>"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Retail and Food Services Sales\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Source:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"\<\"U.S. Department of Commerce: Census Bureau\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Release:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Advance Monthly Sales for Retail and Food Services\"\>",
           ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Units:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Millions of Dollars\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Frequency:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Monthly\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Seasonal Adjustment:\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Not Seasonally Adjusted\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Vintage Dates Specified:\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"observation_date\"\>", ",", "\<\"RSAFSNA\"\>", 
          ",", "\<\"realtime_start_date\"\>", 
          ",", "\<\"realtime_end_date\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "175708.`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"\[LeftSkeleton]", "177", "\[RightSkeleton]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "344966.`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}]}], "}"}]}], "}"}], "}"}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972060214072*^9}]
}, Open  ]],

Cell["\<\
The output from these three examples show that the next step is to determine \
how to process the data.\
\>", "Text",
 CellChangeTimes->{{3.469900486376038*^9, 3.4699004890785522`*^9}, {
  3.46990054556223*^9, 3.469900573384554*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Processing raw FRED\[RegisteredTrademark] data", "Section",
 CellChangeTimes->{{3.469900577252089*^9, 3.46990059817171*^9}}],

Cell[CellGroupData[{

Cell["Processing XML formatted data", "Subsubsection",
 CellChangeTimes->{{3.46988402546025*^9, 3.469884040226597*^9}, {
  3.469884441133628*^9, 3.469884441739871*^9}, {3.469969913584551*^9, 
  3.469969914347822*^9}, {3.469970188392763*^9, 3.4699701909283*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"FRED4", "[", 
    RowBox[{"\"\<RSAFSNA\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"tmp", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469808997786611*^9, 3.469809040850843*^9}, {
   3.469809437531247*^9, 3.469809453545568*^9}, {3.4698189735997953`*^9, 
   3.469818993618635*^9}, 3.4698198752387457`*^9, {3.4698202845768623`*^9, 
   3.469820292252246*^9}, 3.469820333049876*^9, 3.469821525038007*^9, {
   3.469822399640111*^9, 3.469822427031331*^9}, 3.46982249249816*^9, 
   3.469881675737611*^9, 3.469881861582975*^9, {3.469881891964717*^9, 
   3.469881892261992*^9}, {3.469882870661049*^9, 3.469882871243243*^9}, {
   3.4698829640637417`*^9, 3.4698829650610447`*^9}, {3.4698840455497427`*^9, 
   3.4698840461249943`*^9}, {3.469884448582613*^9, 3.469884449125923*^9}, {
   3.469900978695262*^9, 3.469900983643528*^9}, 3.469969924285338*^9, {
   3.469972161650552*^9, 3.469972163151807*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"XMLObject", "[", "\<\"Document\"\>", "]"}], "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"XMLObject", "[", "\<\"Declaration\"\>", "]"}], "[", 
       RowBox[{
        RowBox[{"\<\"Version\"\>", "\[Rule]", "\<\"1.0\"\>"}], ",", 
        RowBox[{"\<\"Encoding\"\>", "\[Rule]", "\<\"utf-8\"\>"}]}], "]"}], 
      "}"}], ",", 
     RowBox[{"XMLElement", "[", 
      RowBox[{"\<\"observations\"\>", ",", 
       RowBox[{"{", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-01-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"175708\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-02-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"172518\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-03-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"201710\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-04-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"196468\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-05-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"210945\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"\[LeftSkeleton]", "169", "\[RightSkeleton]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}], ",", 
         RowBox[{"XMLElement", "[", 
          RowBox[{"\<\"observation\"\>", ",", 
           RowBox[{"{", 
            RowBox[{
             
             RowBox[{"\<\"realtime_start\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             
             RowBox[{"\<\"realtime_end\"\>", 
              "\[Rule]", "\<\"2009-12-16\"\>"}], ",", 
             RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
             RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}], 
           ",", 
           RowBox[{"{", "}"}]}], "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", "}"}]}], "]"}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972060743997*^9}]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Cases",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Cases"],
 " can be used to extract the relevant XML data from the download, the \
\"observation\" data:"
}], "Text",
 CellChangeTimes->{{3.469901024724169*^9, 3.4699010422111797`*^9}, {
   3.469901082685979*^9, 3.469901097564784*^9}, 3.4699058728105087`*^9, {
   3.4699699495449266`*^9, 3.4699699495460253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"tmp", ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\"\<observation\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"___", ",", 
        RowBox[{"\"\<date\>\"", "\[Rule]", "_"}], ",", 
        RowBox[{"\"\<value\>\"", "\[Rule]", "_"}]}], "}"}], ",", "___"}], 
     "]"}], ",", "\[Infinity]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4699010527126837`*^9, 3.469901060230577*^9}, {
  3.469901104576002*^9, 3.469901119704363*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-01-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"175708\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-02-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"172518\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-03-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"201710\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-04-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"196468\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-05-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"210945\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"1995-06-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"212305\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"\[LeftSkeleton]", "168", "\[RightSkeleton]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-07-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"354316\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-08-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"359483\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-09-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"330411\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-10-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344797\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}], ",", 
    RowBox[{"XMLElement", "[", 
     RowBox[{"\<\"observation\"\>", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\<\"realtime_start\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"realtime_end\"\>", "\[Rule]", "\<\"2009-12-16\"\>"}], 
        ",", 
        RowBox[{"\<\"date\"\>", "\[Rule]", "\<\"2009-11-01\"\>"}], ",", 
        RowBox[{"\<\"value\"\>", "\[Rule]", "\<\"344966\"\>"}]}], "}"}], ",", 
      
      RowBox[{"{", "}"}]}], "]"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972060807377*^9}]
}, Open  ]],

Cell["\<\
Pattern matching can be used to extract the data from these lists:\
\>", "Text",
 CellChangeTimes->{{3.4699011245086*^9, 3.4699011483041983`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"tmp", ",", 
    RowBox[{
     RowBox[{"XMLElement", "[", 
      RowBox[{"\"\<observation\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"___", ",", 
         RowBox[{"\"\<date\>\"", "\[Rule]", "x_"}], ",", 
         RowBox[{"\"\<value\>\"", "\[Rule]", "y_"}]}], "}"}], ",", "___"}], 
      "]"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ",", "\[Infinity]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469884481304227*^9, 3.469884484719159*^9}, {
  3.4698845668772182`*^9, 3.469884601738302*^9}, {3.4699011625149393`*^9, 
  3.469901195833873*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"1995-01-01\"\>", ",", "\<\"175708\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-02-01\"\>", ",", "\<\"172518\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-03-01\"\>", ",", "\<\"201710\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-04-01\"\>", ",", "\<\"196468\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-05-01\"\>", ",", "\<\"210945\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-06-01\"\>", ",", "\<\"212305\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-07-01\"\>", ",", "\<\"203855\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-08-01\"\>", ",", "\<\"214727\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-09-01\"\>", ",", "\<\"202629\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-10-01\"\>", ",", "\<\"204518\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-11-01\"\>", ",", "\<\"212658\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1995-12-01\"\>", ",", "\<\"248088\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-01-01\"\>", ",", "\<\"185431\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-02-01\"\>", ",", "\<\"192849\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-03-01\"\>", ",", "\<\"212612\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-04-01\"\>", ",", "\<\"212224\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-05-01\"\>", ",", "\<\"227466\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-06-01\"\>", ",", "\<\"218015\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-07-01\"\>", ",", "\<\"218597\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-08-01\"\>", ",", "\<\"226551\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-09-01\"\>", ",", "\<\"209687\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-10-01\"\>", ",", "\<\"223135\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-11-01\"\>", ",", "\<\"224390\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1996-12-01\"\>", ",", "\<\"258604\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1997-01-01\"\>", ",", "\<\"200739\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1997-02-01\"\>", ",", "\<\"197913\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1997-03-01\"\>", ",", "\<\"225488\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1997-04-01\"\>", ",", "\<\"220694\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"1997-05-01\"\>", ",", "\<\"234583\"\>"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "122", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2007-08-01\"\>", ",", "\<\"387261\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2007-09-01\"\>", ",", "\<\"353159\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2007-10-01\"\>", ",", "\<\"367855\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2007-11-01\"\>", ",", "\<\"376822\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2007-12-01\"\>", ",", "\<\"425283\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-01-01\"\>", ",", "\<\"342191\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-02-01\"\>", ",", "\<\"344062\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-03-01\"\>", ",", "\<\"373587\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-04-01\"\>", ",", "\<\"370144\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-05-01\"\>", ",", "\<\"399979\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-06-01\"\>", ",", "\<\"380431\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-07-01\"\>", ",", "\<\"385909\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-08-01\"\>", ",", "\<\"384798\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-09-01\"\>", ",", "\<\"352554\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-10-01\"\>", ",", "\<\"352479\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-11-01\"\>", ",", "\<\"338788\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2008-12-01\"\>", ",", "\<\"387964\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-01-01\"\>", ",", "\<\"313593\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-02-01\"\>", ",", "\<\"304056\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-03-01\"\>", ",", "\<\"334149\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-04-01\"\>", ",", "\<\"336155\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-05-01\"\>", ",", "\<\"354668\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-06-01\"\>", ",", "\<\"351418\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-07-01\"\>", ",", "\<\"354316\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-08-01\"\>", ",", "\<\"359483\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-09-01\"\>", ",", "\<\"330411\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-10-01\"\>", ",", "\<\"344797\"\>"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"2009-11-01\"\>", ",", "\<\"344966\"\>"}], "}"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.46997206087403*^9}]
}, Open  ]],

Cell[TextData[{
 "Each element in the list is a string. The date strings need to be converted \
to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " date lists and the number strings to numbers. ",
 ButtonBox["DateList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DateList"],
 " accomplishes the first task. ",
 ButtonBox["ToExpression",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ToExpression"],
 " accomplished the second task. However, in the event that some numbers have \
commas, the commas should be removed prior to applying ",
 StyleBox["ToExpression", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.469901201064272*^9, 3.469901304377183*^9}, {
  3.469969986046541*^9, 3.4699700310295153`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stringToNumber", "[", "x_String", "]"}], ":=", 
   RowBox[{"ToExpression", "[", 
    RowBox[{"StringReplace", "[", 
     RowBox[{"x", ",", 
      RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"tmp", ",", 
    RowBox[{
     RowBox[{"XMLElement", "[", 
      RowBox[{"\"\<observation\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"___", ",", 
         RowBox[{"\"\<date\>\"", "\[Rule]", "x_"}], ",", 
         RowBox[{"\"\<value\>\"", "\[Rule]", "y_"}]}], "}"}], ",", "___"}], 
      "]"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateList", "@", "x"}], ",", 
       RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469884481304227*^9, 3.469884484719159*^9}, {
  3.4698845668772182`*^9, 3.469884601738302*^9}, {3.469901337767294*^9, 
  3.469901338308908*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "175708"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "172518"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "201710"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "196468"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "210945"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212305"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "203855"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "214727"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "202629"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "204518"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212658"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "248088"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "185431"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "192849"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212612"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212224"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "227466"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "218015"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "218597"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "226551"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "209687"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "223135"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "224390"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "258604"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "131", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "425283"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "342191"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344062"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "373587"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "370144"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "399979"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "380431"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "385909"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "384798"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "352554"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "352479"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "338788"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "387964"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "313593"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "304056"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "334149"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "336155"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "354668"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "351418"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "354316"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "359483"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "330411"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344797"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344966"}], "}"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972061501932*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Processing Excel formatted data\
\>", "Subsubsection",
 CellChangeTimes->{{3.46988402546025*^9, 3.469884040226597*^9}, {
  3.469970172995203*^9, 3.46997018200019*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"FRED4", "[", 
    RowBox[{"\"\<TWEXB\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"tmp", ",", "60"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469808997786611*^9, 3.469809040850843*^9}, {
   3.469809437531247*^9, 3.469809453545568*^9}, {3.4698189735997953`*^9, 
   3.469818993618635*^9}, 3.4698198752387457`*^9, {3.4698202845768623`*^9, 
   3.469820292252246*^9}, 3.469820333049876*^9, 3.469821525038007*^9, {
   3.469822399640111*^9, 3.469822427031331*^9}, 3.46982249249816*^9, 
   3.469881675737611*^9, 3.469881861582975*^9, {3.469881891964717*^9, 
   3.469881892261992*^9}, {3.469882870661049*^9, 3.469882871243243*^9}, {
   3.4698829640637417`*^9, 3.4698829650610447`*^9}, {3.4698840455497427`*^9, 
   3.4698840461249943`*^9}, {3.4698877369063396`*^9, 3.46988777304858*^9}, {
   3.469887808075169*^9, 3.4698878320738897`*^9}, {3.46988788862368*^9, 
   3.469887888962549*^9}, {3.469901365144231*^9, 3.469901400496314*^9}, {
   3.469970093131846*^9, 3.469970106539344*^9}, {3.469972172753029*^9, 
   3.46997217378447*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"Series ID: TWEXB\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Link: \
http://alfred.stlouisfed.org/series?seid=TWEXB\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Help: http://alfred.stlouisfed.org/help\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"ALFRED (ArchivaL Federal Reserve Economic Data)\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Economic Research Division\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Federal Reserve Bank of St. Louis\"\>", ",", "\<\"\"\>",
           ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Output Format: Observations by Real-Time Period\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"File Created: 2009-12-16 11:07 AM CST\"\>", 
          ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"Real-Time\"\>", 
          ",", "\<\" Period\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Title:\"\>", ",", "\<\"Start\"\>", ",", "\<\"End\"\>"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Trade Weighted Exchange Index: Broad\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Source:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Board of Governors of the Federal Reserve System\"\>", 
          ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Release:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"H.10 Foreign Exchange Rates\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Units:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Index January 1997=100\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Frequency:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Weekly, Ending Wednesday\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Seasonal Adjustment:\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Not Applicable\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Notes:\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Averages of daily figures. A weighted average of the \
foreign exchange\"\>", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"value of the U.S. dollar against the currencies of a \
broad group of\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"major U.S. trading partners.\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Broad currency index includes the Euro Area, Canada, \
Japan, Mexico,\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"China, United Kingdom, Taiwan, Korea, Singapore, Hong \
Kong, Malaysia,\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Brazil, Switzerland, Thailand, Philippines, Australia, \
Indonesia,\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"India, Israel, Saudi Arabia, Russia, Sweden, Argentina, \
Venezuela,\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Chile and Colombia.\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"For more information about trade-weighted indexes see\"\
\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"http://www.federalreserve.gov/pubs/bulletin/2005/\
winter05_index.pdf.\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"Vintage Dates Specified:\"\>", ",", "\<\"\"\>", 
          ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"\"\>", ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "\<\"\"\>", ",", "\<\"\"\>"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"observation_date\"\>", ",", "\<\"TWEXB\"\>", 
          ",", "\<\"realtime_start_date\"\>", 
          ",", "\<\"realtime_end_date\"\>"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "1", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "94.35`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "1", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "94.32`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "1", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "93.8`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "1", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "94.05`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "94.06`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "2", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "93.69`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "2", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "93.92`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "2", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "93.49`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "93.3`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "3", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "92.86`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "3", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "92.76`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "3", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "92.98`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "3", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "92.48`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "4", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "91.67`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "4", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "90.65`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "4", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "89.74`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "4", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "89.61`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "5", ",", "3", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "89.58`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "1995", ",", "5", ",", "10", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "89.28`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"\[LeftSkeleton]", "741", "\[RightSkeleton]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "7", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.62`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "8", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "102.98`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "8", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.44`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "8", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.6`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "8", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.12`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "9", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.73`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "9", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.52`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "9", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.04`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "9", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "102.63`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "103.03`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "10", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "102.68`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "10", ",", "14", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.41`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "10", ",", "21", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.07`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "10", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.73`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "11", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "102.12`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "11", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.54`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "11", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.02`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "11", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.02`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "100.56`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "101.01`", ",", 
          RowBox[{"{", 
           RowBox[{
           "2009", ",", "12", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
           "}"}], ",", "0.`"}], "}"}]}], "}"}]}], "}"}], "}"}], "}"}],
  Short[#, 60]& ]], "Output",
 CellChangeTimes->{3.46997206330534*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " automatically converts Excel dates to date lists. To extract the data we \
look for patterns in lists that contain {date list, number, \[Ellipsis]}:"
}], "Text",
 CellChangeTimes->{{3.469901435741647*^9, 3.469901511829934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"tmp", ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", ":", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"_", "?", "NumericQ"}], ",", "_", ",", "_", ",", "__"}], 
         "}"}]}], ",", 
       RowBox[{"y_", "?", "NumericQ"}], ",", "___"}], "}"}], "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], ",", "\[Infinity]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4698835452770987`*^9, 3.469883595610981*^9}, {
  3.4698836881670732`*^9, 3.46988369811766*^9}, {3.4698837585608377`*^9, 
  3.469883787792131*^9}, {3.469883819899193*^9, 3.4698838521692057`*^9}, {
  3.469883928083898*^9, 3.4698839890528507`*^9}, {3.469884159415144*^9, 
  3.469884198992422*^9}, {3.469884255211042*^9, 3.4698843002357473`*^9}, {
  3.469884335604806*^9, 3.469884372300256*^9}, {3.469901529362837*^9, 
  3.469901529913027*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "94.35`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "94.32`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "93.8`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "94.05`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "94.06`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "93.69`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "93.92`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "93.49`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "93.3`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "92.86`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "92.76`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "92.98`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "92.48`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "91.67`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.65`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "89.74`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "89.61`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "3", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "89.58`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "10", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "89.28`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "17", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.62`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "24", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.99`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "6", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.41`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "6", ",", "14", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "90.34`"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "733", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "105.61`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "105.57`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "104.18`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.62`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "102.98`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.44`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.6`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.12`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.73`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.52`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.04`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "102.63`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "103.03`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "102.68`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "14", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.41`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "21", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.07`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "28", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.73`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "102.12`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "11", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.54`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "18", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.02`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "25", ",", "0", ",", "0", ",", "0.`"}],
        "}"}], ",", "101.02`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "12", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "100.56`"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "12", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "101.01`"}], "}"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.469972063489698*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Processing text data", "Subsubsection",
 CellChangeTimes->{{3.46988402546025*^9, 3.4698840270586853`*^9}, {
  3.469970198913368*^9, 3.469970204864743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp", "=", 
   RowBox[{"FRED4", "[", 
    RowBox[{"\"\<RSAFSNA\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"1995", ",", "01", ",", "04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
     RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<txt\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"tmp", ",", "40"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469808997786611*^9, 3.469809040850843*^9}, {
   3.469809437531247*^9, 3.469809453545568*^9}, {3.4698189735997953`*^9, 
   3.469818993618635*^9}, 3.4698198752387457`*^9, {3.4698202845768623`*^9, 
   3.469820292252246*^9}, 3.469820333049876*^9, 3.469821525038007*^9, {
   3.469822399640111*^9, 3.469822427031331*^9}, 3.46982249249816*^9, 
   3.469881675737611*^9, 3.469881861582975*^9, {3.469881891964717*^9, 
   3.469881892261992*^9}, {3.469882870661049*^9, 3.469882871243243*^9}, {
   3.4698829640637417`*^9, 3.4698829650610447`*^9}, {3.469901632357148*^9, 
   3.469901647229865*^9}, {3.469970144403698*^9, 3.469970150764086*^9}, {
   3.469972187673461*^9, 3.4699721888564787`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"\<\"Series ID: RSAFSNA\\nLink: \
http://alfred.stlouisfed.org/series?seid=RSAFSNA\\nHelp: \
http://alfred.stlouisfed.org/help\\n\\nALFRED (ArchivaL Federal Reserve \
Economic Data)\\nEconomic Research Division\\nFederal Reserve Bank of St. \
Louis\\n\\nOutput Format: Observations by Real-Time Period\\nFile Created: \
2009-12-16 11:07 AM CST\\n\\n                                                 \
                            Real-Time Period     \\nTitle                     \
                                                  Start         End     \
\\n---------------------------------------------------------------------------\
-----------------------\\nRetail and Food Services Sales                      \
                      2009-12-16   2009-12-16 \
\\n\\nSource\\n---------------------------------------------------------------\
-----------------------------------\\nU.S. Department of Commerce: Census \
Bureau                                2009-12-16   2009-12-16 \
\\n\\nRelease\\n--------------------------------------------------------------\
------------------------------------\\nAdvance Monthly Sales for Retail and \
Food Services                        2009-12-16   2009-12-16 \
\\n\\nUnits\\n----------------------------------------------------------------\
----------------------------------\\nMillions of Dollars                      \
                                 2009-12-16   2009-12-16 \
\\n\\nFrequency\\n------------------------------------------------------------\
--------------------------------------\\nMonthly                              \
                                     2009-12-16   2009-12-16 \\n\\nSeasonal \
Adjustment\\n-----------------------------------------------------------------\
---------------------------------\\nNot Seasonally Adjusted                   \
                                2009-12-16   2009-12-16 \\n\\n\\nVintage \
Dates Specified:\\n\\n2009-12-16\"\>", ",", 
     RowBox[{"\<\"observation_date\\tRSAFSNA\\trealtime_start_date\\trealtime_\
end_date\\n1995-01-01\\t175708\\t2009-12-16\\t.\\n1995-02-01\\t172518\\t2009-\
12-16\\t.\\n1995-03-01\\t201710\\t2009-12-16\\t.\\n1995-04-01\\t196468\\t2009-\
12-16\\t.\\n1995-05-01\\t210945\\t2009-12-16\\t.\\n1995-06-01\\t212305\\t2009-\
12-16\\t.\\n1995-07-01\\t203855\\t2009-12-16\\t.\\n1995-08-01\\t214727\\t2009-\
12-16\\t.\\n1995-09-01\\t202629\\t2009-12-16\\t.\\n1995-10-01\\t204518\\t2009-\
12-16\\t.\\n1995-11-01\\t212658\\t2009-12-16\\t.\\n1995-12-01\\t248088\\t2009-\
12-16\\t.\\n1996-01-01\\t185431\\t2009-12-16\\t.\\n1996-0\"\>", 
      "\[Ellipsis]", \
"\<\"12-16\\t.\\n2008-09-01\\t352554\\t2009-12-16\\t.\\n2008-10-01\\t352479\\\
t2009-12-16\\t.\\n2008-11-01\\t338788\\t2009-12-16\\t.\\n2008-12-01\\t387964\\\
t2009-12-16\\t.\\n2009-01-01\\t313593\\t2009-12-16\\t.\\n2009-02-01\\t304056\\\
t2009-12-16\\t.\\n2009-03-01\\t334149\\t2009-12-16\\t.\\n2009-04-01\\t336155\\\
t2009-12-16\\t.\\n2009-05-01\\t354668\\t2009-12-16\\t.\\n2009-06-01\\t351418\\\
t2009-12-16\\t.\\n2009-07-01\\t354316\\t2009-12-16\\t.\\n2009-08-01\\t359483\\\
t2009-12-16\\t.\\n2009-09-01\\t330411\\t2009-12-16\\t.\\n2009-10-01\\t344797\\\
t2009-12-16\\t.\\n2009-11-01\\t344966\\t2009-12-16\\t.\"\>"}]}], "}"}], "}"}],
  
  Short[#, 40]& ]], "Output",
 CellChangeTimes->{3.469972063891754*^9}]
}, Open  ]],

Cell["\<\
The data in the text file is tab delimited. The first thing to do is to split \
the string at the line breaks and then secondly at the tabs:\
\>", "Text",
 CellChangeTimes->{{3.469901657586645*^9, 3.4699016771296043`*^9}, {
  3.469970220292205*^9, 3.469970236337854*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"StringSplit", "[", 
      RowBox[{"#", ",", "\"\<\\t\>\""}], "]"}], "&"}], "/@", 
    RowBox[{"StringSplit", "[", 
     RowBox[{
      RowBox[{"First", "[", "tmp", "]"}], ",", "\"\<\\n\>\""}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"tmp1", ",", "60"}], "]"}]}], "Input",
 CellChangeTimes->{{3.469882984169238*^9, 3.469882984644023*^9}, {
  3.4698832892628593`*^9, 3.469883340972501*^9}, {3.4698834195290213`*^9, 
  3.4698834338715363`*^9}, {3.469901702198649*^9, 3.469901705397224*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "\<\"Series ID: RSAFSNA\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Link: http://alfred.stlouisfed.org/series?seid=RSAFSNA\"\>", 
       "}"}], ",", 
      RowBox[{"{", "\<\"Help: http://alfred.stlouisfed.org/help\"\>", "}"}], 
      ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{
      "{", "\<\"ALFRED (ArchivaL Federal Reserve Economic Data)\"\>", "}"}], 
      ",", 
      RowBox[{"{", "\<\"Economic Research Division\"\>", "}"}], ",", 
      RowBox[{"{", "\<\"Federal Reserve Bank of St. Louis\"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{
      "{", "\<\"Output Format: Observations by Real-Time Period\"\>", "}"}], 
      ",", 
      RowBox[{"{", "\<\"File Created: 2009-12-16 11:07 AM CST\"\>", "}"}], 
      ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{
      "{", "\<\"                                                              \
               Real-Time Period     \"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Title                                                         \
              Start         End     \"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Retail and Food Services Sales                                \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Source\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"U.S. Department of Commerce: Census Bureau                    \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Release\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Advance Monthly Sales for Retail and Food Services            \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Units\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Millions of Dollars                                           \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Frequency\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Monthly                                                       \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Seasonal Adjustment\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"--------------------------------------------------------------\
------------------------------------\"\>", "}"}], ",", 
      RowBox[{
      "{", "\<\"Not Seasonally Adjusted                                       \
            2009-12-16   2009-12-16 \"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"Vintage Dates Specified:\"\>", "}"}], ",", 
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", "\<\"2009-12-16\"\>", "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"observation_date\"\>", ",", "\<\"RSAFSNA\"\>", 
        ",", "\<\"realtime_start_date\"\>", 
        ",", "\<\"realtime_end_date\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-01-01\"\>", ",", "\<\"175708\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-02-01\"\>", ",", "\<\"172518\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-03-01\"\>", ",", "\<\"201710\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-04-01\"\>", ",", "\<\"196468\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-05-01\"\>", ",", "\<\"210945\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-06-01\"\>", ",", "\<\"212305\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-07-01\"\>", ",", "\<\"203855\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-08-01\"\>", ",", "\<\"214727\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-09-01\"\>", ",", "\<\"202629\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-10-01\"\>", ",", "\<\"204518\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-11-01\"\>", ",", "\<\"212658\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1995-12-01\"\>", ",", "\<\"248088\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-01-01\"\>", ",", "\<\"185431\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-02-01\"\>", ",", "\<\"192849\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-03-01\"\>", ",", "\<\"212612\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-04-01\"\>", ",", "\<\"212224\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-05-01\"\>", ",", "\<\"227466\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-06-01\"\>", ",", "\<\"218015\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-07-01\"\>", ",", "\<\"218597\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-08-01\"\>", ",", "\<\"226551\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-09-01\"\>", ",", "\<\"209687\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-10-01\"\>", ",", "\<\"223135\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-11-01\"\>", ",", "\<\"224390\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1996-12-01\"\>", ",", "\<\"258604\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1997-01-01\"\>", ",", "\<\"200739\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"1997-02-01\"\>", ",", "\<\"197913\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"\[LeftSkeleton]", "127", "\[RightSkeleton]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2007-10-01\"\>", ",", "\<\"367855\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2007-11-01\"\>", ",", "\<\"376822\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2007-12-01\"\>", ",", "\<\"425283\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-01-01\"\>", ",", "\<\"342191\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-02-01\"\>", ",", "\<\"344062\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-03-01\"\>", ",", "\<\"373587\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-04-01\"\>", ",", "\<\"370144\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-05-01\"\>", ",", "\<\"399979\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-06-01\"\>", ",", "\<\"380431\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-07-01\"\>", ",", "\<\"385909\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-08-01\"\>", ",", "\<\"384798\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-09-01\"\>", ",", "\<\"352554\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-10-01\"\>", ",", "\<\"352479\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-11-01\"\>", ",", "\<\"338788\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2008-12-01\"\>", ",", "\<\"387964\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-01-01\"\>", ",", "\<\"313593\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-02-01\"\>", ",", "\<\"304056\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-03-01\"\>", ",", "\<\"334149\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-04-01\"\>", ",", "\<\"336155\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-05-01\"\>", ",", "\<\"354668\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-06-01\"\>", ",", "\<\"351418\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-07-01\"\>", ",", "\<\"354316\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-08-01\"\>", ",", "\<\"359483\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-09-01\"\>", ",", "\<\"330411\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-10-01\"\>", ",", "\<\"344797\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"2009-11-01\"\>", ",", "\<\"344966\"\>", 
        ",", "\<\"2009-12-16\"\>", ",", "\<\".\"\>"}], "}"}]}], "}"}]}], "}"}],
  Short[#, 60]& ]], "Output",
 CellChangeTimes->{3.469972063957494*^9}]
}, Open  ]],

Cell["\<\
Next, extract the data via pattern matching. The pattern to match is a list \
with the second element being a number string. Whether or not the second \
element is a number string is tested by applying a condition. Note that any \
commas that may be present in the string are removed prior to testing if the \
string is a number string.\
\>", "Text",
 CellChangeTimes->{{3.469883529271484*^9, 3.4698835353833323`*^9}, {
  3.469901717844369*^9, 3.4699017792918863`*^9}, {3.469970255988103*^9, 
  3.4699703392128468`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"tmp1", ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x_String", ",", 
       RowBox[{"y_String", "/;", 
        RowBox[{"StringMatchQ", "[", 
         RowBox[{
          RowBox[{"StringReplace", "[", 
           RowBox[{"y", ",", 
            RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], ",", 
          "NumberString"}], "]"}]}], ",", "__"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"DateList", "@", "x"}], ",", 
       RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", "\[Infinity]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Short", "[", 
  RowBox[{"%", ",", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4698835452770987`*^9, 3.469883595610981*^9}, {
  3.4698836881670732`*^9, 3.46988369811766*^9}, {3.4698837585608377`*^9, 
  3.469883787792131*^9}, {3.469883819899193*^9, 3.4698838521692057`*^9}, {
  3.469883928083898*^9, 3.4698839890528507`*^9}, {3.469901795130975*^9, 
  3.4699018058175697`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "175708"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "172518"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "201710"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "196468"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "210945"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212305"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "203855"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "214727"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "202629"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "204518"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212658"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1995", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "248088"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "185431"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "192849"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212612"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "212224"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "227466"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "218015"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "218597"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "226551"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "209687"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "223135"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "224390"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1996", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "258604"}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "131", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "425283"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "342191"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344062"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "373587"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "370144"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "399979"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "380431"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "385909"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "384798"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "352554"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "352479"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "338788"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "387964"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "313593"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "304056"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "334149"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "336155"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "354668"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "351418"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "354316"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "359483"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "330411"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344797"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
       "}"}], ",", "344966"}], "}"}]}], "}"}],
  Short[#, 20]& ]], "Output",
 CellChangeTimes->{3.46997206458491*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Including steps to process the data", "Section",
 CellChangeTimes->{{3.4699025853280907`*^9, 3.4699026008313713`*^9}}],

Cell[TextData[{
 "Having determined how to process the data, the next step is to include a \
test in the ",
 StyleBox["FRED", "MB"],
 " function to test the file type then process the data based on the file \
type. This can be accomplished using ",
 ButtonBox["Switch",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Switch"],
 "."
}], "Text",
 CellChangeTimes->{{3.46990260345477*^9, 3.4699026553437967`*^9}, {
  3.469970412384575*^9, 3.46997043999946*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FRED5", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<lin\>\""}], ",", 
      RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<1\>\""}], ",", 
      RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FRED5", "[", 
   RowBox[{
    RowBox[{"series", ":", 
     RowBox[{"(", 
      RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_", ",", 
    "endDate_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "start1", ",", "end1", ",", "opts1", ",", "queryString", ",", "fileType",
       ",", "extension", ",", "tmp", ",", "tmp1"}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"collect", " ", "options"}], " ", "*)"}], "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"opts1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<units\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<units\>\"", "]"}]}], ",", 
        RowBox[{"\"\<output_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<output_type\>\"", "]"}]}], ",", 
        RowBox[{"\"\<file_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], "}"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "date", " ", "strings"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "query", " ", "string", " ", "insert"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"queryString", "=", 
      RowBox[{"makeQueryString", "[", "opts1", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "determine", " ", "second", " ", "argument", " ", "for", " ", 
       "Import"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fileType", "=", 
      RowBox[{"ToLowerCase", "@", 
       RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"extension", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "fileType", ",", "\"\<xml\>\"", ",", "\"\<XML\>\"", ",", "\"\<xls\>\"",
         ",", "\"\<*\>\"", ",", "\"\<txt\>\"", ",", "\"\<*\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"tmp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Import", "[", 
         RowBox[{
          RowBox[{
          "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\
\"", "<>", 
           RowBox[{"ToString", "[", "#", "]"}], "<>", 
           "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
           "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&\>\"", "<>",
            "queryString", "<>", "\"\<&api_key=\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}], ",", "extension"}], "]"}], "&"}], 
       "/@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "series", "}"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"fileType", ",", "\[IndentingNewLine]", "\"\<xml\>\"", ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"XMLElement", "[", 
           RowBox[{"\"\<observation\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"___", ",", 
              RowBox[{"\"\<date\>\"", "\[Rule]", "x_"}], ",", 
              RowBox[{"\"\<value\>\"", "\[Rule]", "y_"}]}], "}"}], ",", 
            "___"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"DateList", "@", "x"}], ",", 
            RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "4"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<xls\>\"", ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", ":", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"_", "?", "NumericQ"}], ",", "_", ",", "_", ",", 
               "__"}], "}"}]}], ",", 
            RowBox[{"y_", "?", "NumericQ"}], ",", "___"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], ",", "\[Infinity]"}], "]"}], ",",
        "\[IndentingNewLine]", "\"\<txt\>\"", ",", 
       RowBox[{
        RowBox[{"tmp1", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"StringSplit", "[", 
            RowBox[{"#", ",", "\"\<\\t\>\""}], "]"}], "&"}], "/@", 
          RowBox[{"StringSplit", "[", 
           RowBox[{
            RowBox[{"First", "[", "tmp", "]"}], ",", "\"\<\\n\>\""}], 
           "]"}]}]}], ";", 
        RowBox[{"Cases", "[", 
         RowBox[{"tmp1", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x_String", ",", 
             RowBox[{"y_String", "/;", 
              RowBox[{"StringMatchQ", "[", 
               RowBox[{
                RowBox[{"StringReplace", "[", 
                 RowBox[{"y", ",", 
                  RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], ",", 
                "NumberString"}], "]"}]}], ",", "__"}], "}"}], 
           "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"DateList", "@", "x"}], ",", 
             RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
          "\[Infinity]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.466015991030652*^9, 3.466016032564374*^9}, {
   3.466016139573862*^9, 3.466016141507875*^9}, {3.466016225001635*^9, 
   3.4660162538892927`*^9}, 3.466016336130364*^9, 3.466016489597485*^9, {
   3.466016541311713*^9, 3.466016541620955*^9}, 3.466016652146227*^9, {
   3.466016691086628*^9, 3.466016725243649*^9}, {3.466016917507864*^9, 
   3.46601694496313*^9}, {3.466016993944916*^9, 3.4660169949167337`*^9}, {
   3.4660175359102983`*^9, 3.4660175410410852`*^9}, {3.4698089330911703`*^9, 
   3.4698089935073767`*^9}, {3.469809325244069*^9, 3.4698094289006767`*^9}, {
   3.4698188781505823`*^9, 3.4698188971181383`*^9}, {3.469819722218762*^9, 
   3.4698197368973913`*^9}, {3.4698198624750767`*^9, 3.469819868514059*^9}, {
   3.469820228619958*^9, 3.469820260620138*^9}, {3.4698203018703117`*^9, 
   3.469820304452364*^9}, {3.469821256669025*^9, 3.4698212707624607`*^9}, {
   3.469821470599915*^9, 3.469821508368984*^9}, {3.4698220790002613`*^9, 
   3.469822089726617*^9}, {3.469822152873584*^9, 3.4698221608092527`*^9}, {
   3.469822214483282*^9, 3.4698222420378027`*^9}, {3.4698222885848513`*^9, 
   3.4698223790205927`*^9}, {3.469881410297741*^9, 3.4698814464513807`*^9}, {
   3.4698815885450897`*^9, 3.4698816594636507`*^9}, {3.46988193111939*^9, 
   3.4698819565702887`*^9}, {3.469881996993034*^9, 3.469882068731903*^9}, {
   3.4698820994778976`*^9, 3.469882133117625*^9}, 3.4698824347125273`*^9, {
   3.4698824727529707`*^9, 3.469882512291389*^9}, {3.4698825551230717`*^9, 
   3.469882558700638*^9}, {3.4698826809276953`*^9, 3.4698826831334257`*^9}, {
   3.469882789082679*^9, 3.46988281516654*^9}, 3.4698828822658863`*^9, {
   3.4698844710805283`*^9, 3.4698844723168364`*^9}, {3.469884617837785*^9, 
   3.4698846212920847`*^9}, {3.469885122154298*^9, 3.469885129072653*^9}, {
   3.46988776822069*^9, 3.469887768564498*^9}, {3.469887893158313*^9, 
   3.469887893477867*^9}, {3.46989661627166*^9, 3.46989661983704*^9}, {
   3.469896726250222*^9, 3.469896726773631*^9}, {3.469898312778471*^9, 
   3.46989831509131*^9}, {3.469898378775655*^9, 3.4698983962987022`*^9}, {
   3.469898762705505*^9, 3.469898799822164*^9}, 3.469899214607335*^9, 
   3.4698992556719313`*^9, {3.4698993150610847`*^9, 3.469899320032398*^9}, {
   3.469899443332966*^9, 3.469899448202669*^9}, {3.469899809660198*^9, 
   3.469899832611311*^9}, {3.469899899024125*^9, 3.4698998992362843`*^9}, {
   3.469900259231855*^9, 3.46990027815175*^9}, {3.4699003139697313`*^9, 
   3.46990037482163*^9}, {3.469902673882393*^9, 3.4699027116755133`*^9}, 
   3.469902787364902*^9, {3.469903001695986*^9, 3.469903031057207*^9}, {
   3.469903900469575*^9, 3.469903900817958*^9}, {3.4699039461480627`*^9, 
   3.469903946372654*^9}, {3.469967675716851*^9, 3.4699676946865463`*^9}, 
   3.469970453326742*^9, {3.469970486415552*^9, 3.469970503012023*^9}, 
   3.470140477208363*^9}],

Cell[TextData[{
 "Finally, if you want to share the ",
 StyleBox["FRED", "MB"],
 " function with others you want to make it easy for them to enter their own \
API key. Therefore that parameter can be added to the options list for the \
function:"
}], "Text",
 CellChangeTimes->{{3.469904855337473*^9, 3.469904904242353*^9}, 
   3.469905878762899*^9, {3.469970516659012*^9, 3.4699705224725657`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "FRED", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SyntaxInformation", "[", "FRED", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"\"\<ArgumentsPattern\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_", ",", "_", ",", 
        RowBox[{"OptionsPattern", "[", "]"}]}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FRED", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<lin\>\""}], ",", 
      RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<1\>\""}], ",", 
      RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}], ",", 
      RowBox[{"\"\<api_key\>\"", "\[Rule]", "\"\<\>\""}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FRED", "[", 
   RowBox[{
    RowBox[{"series", ":", 
     RowBox[{"(", 
      RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_", ",", 
    "endDate_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "start1", ",", "end1", ",", "opts1", ",", "queryString", ",", "fileType",
       ",", "extension", ",", "tmp"}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"collect", " ", "options"}], " ", "*)"}], "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"opts1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<units\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<units\>\"", "]"}]}], ",", 
        RowBox[{"\"\<output_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<output_type\>\"", "]"}]}], ",", 
        RowBox[{"\"\<file_type\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}], ",", 
        RowBox[{"\"\<api_key\>\"", "\[Rule]", 
         RowBox[{"OptionValue", "[", "\"\<api_key\>\"", "]"}]}]}], "}"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "date", " ", "strings"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"start1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"startDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"end1", "=", 
      RowBox[{"DateString", "[", 
       RowBox[{"endDate", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
          "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"make", " ", "query", " ", "string", " ", "insert"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"queryString", "=", 
      RowBox[{"makeQueryString", "[", "opts1", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "determine", " ", "second", " ", "argument", " ", "for", " ", 
       "Import"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"fileType", "=", 
      RowBox[{"ToLowerCase", "@", 
       RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"extension", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{
       "fileType", ",", "\"\<xml\>\"", ",", "\"\<XML\>\"", ",", "\"\<xls\>\"",
         ",", "\"\<*\>\"", ",", "\"\<txt\>\"", ",", "\"\<*\>\""}], "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"tmp", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Import", "[", 
         RowBox[{
          RowBox[{
          "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\>\
\"", "<>", 
           RowBox[{"ToString", "[", "#", "]"}], "<>", 
           "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
           "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&\>\"", "<>",
            "queryString"}], ",", "extension"}], "]"}], "&"}], "/@", 
       RowBox[{"Flatten", "[", 
        RowBox[{"{", "series", "}"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"fileType", ",", "\[IndentingNewLine]", "\"\<xml\>\"", ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"XMLElement", "[", 
           RowBox[{"\"\<observation\>\"", ",", 
            RowBox[{"{", 
             RowBox[{"___", ",", 
              RowBox[{"\"\<date\>\"", "\[Rule]", "x_"}], ",", 
              RowBox[{"\"\<value\>\"", "\[Rule]", "y_"}]}], "}"}], ",", 
            "___"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"DateList", "@", "x"}], ",", 
            RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "4"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\"\<xls\>\"", ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", ":", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"_", "?", "NumericQ"}], ",", "_", ",", "_", ",", 
               "__"}], "}"}]}], ",", 
            RowBox[{"y_", "?", "NumericQ"}], ",", "___"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y"}], "}"}]}], ",", "\[Infinity]"}], "]"}], ",",
        "\[IndentingNewLine]", "\"\<txt\>\"", ",", 
       RowBox[{
        RowBox[{"tmp", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"StringSplit", "[", 
            RowBox[{"#", ",", "\"\<\\t\>\""}], "]"}], "&"}], "/@", 
          RowBox[{"StringSplit", "[", 
           RowBox[{
            RowBox[{"First", "[", "tmp", "]"}], ",", "\"\<\\n\>\""}], 
           "]"}]}]}], ";", 
        RowBox[{"Cases", "[", 
         RowBox[{"tmp", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x_String", ",", 
             RowBox[{"y_String", "/;", 
              RowBox[{"StringMatchQ", "[", 
               RowBox[{
                RowBox[{"StringReplace", "[", 
                 RowBox[{"y", ",", 
                  RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], ",", 
                "NumberString"}], "]"}]}], ",", "__"}], "}"}], 
           "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"DateList", "@", "x"}], ",", 
             RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
          "\[Infinity]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.466015991030652*^9, 3.466016032564374*^9}, {
   3.466016139573862*^9, 3.466016141507875*^9}, {3.466016225001635*^9, 
   3.4660162538892927`*^9}, 3.466016336130364*^9, 3.466016489597485*^9, {
   3.466016541311713*^9, 3.466016541620955*^9}, 3.466016652146227*^9, {
   3.466016691086628*^9, 3.466016725243649*^9}, {3.466016917507864*^9, 
   3.46601694496313*^9}, {3.466016993944916*^9, 3.4660169949167337`*^9}, {
   3.4660175359102983`*^9, 3.4660175410410852`*^9}, {3.4698089330911703`*^9, 
   3.4698089935073767`*^9}, {3.469809325244069*^9, 3.4698094289006767`*^9}, {
   3.4698188781505823`*^9, 3.4698188971181383`*^9}, {3.469819722218762*^9, 
   3.4698197368973913`*^9}, {3.4698198624750767`*^9, 3.469819868514059*^9}, {
   3.469820228619958*^9, 3.469820260620138*^9}, {3.4698203018703117`*^9, 
   3.469820304452364*^9}, {3.469821256669025*^9, 3.4698212707624607`*^9}, {
   3.469821470599915*^9, 3.469821508368984*^9}, {3.4698220790002613`*^9, 
   3.469822089726617*^9}, {3.469822152873584*^9, 3.4698221608092527`*^9}, {
   3.469822214483282*^9, 3.4698222420378027`*^9}, {3.4698222885848513`*^9, 
   3.4698223790205927`*^9}, {3.469881410297741*^9, 3.4698814464513807`*^9}, {
   3.4698815885450897`*^9, 3.4698816594636507`*^9}, {3.46988193111939*^9, 
   3.4698819565702887`*^9}, {3.469881996993034*^9, 3.469882068731903*^9}, {
   3.4698820994778976`*^9, 3.469882133117625*^9}, 3.4698824347125273`*^9, {
   3.4698824727529707`*^9, 3.469882512291389*^9}, {3.4698825551230717`*^9, 
   3.469882558700638*^9}, {3.4698826809276953`*^9, 3.4698826831334257`*^9}, {
   3.469882789082679*^9, 3.46988281516654*^9}, 3.4698828822658863`*^9, {
   3.4698844710805283`*^9, 3.4698844723168364`*^9}, {3.469884617837785*^9, 
   3.4698846212920847`*^9}, {3.469885122154298*^9, 3.469885129072653*^9}, {
   3.46988776822069*^9, 3.469887768564498*^9}, {3.469887893158313*^9, 
   3.469887893477867*^9}, {3.46989661627166*^9, 3.46989661983704*^9}, {
   3.469896726250222*^9, 3.469896726773631*^9}, {3.469898312778471*^9, 
   3.46989831509131*^9}, {3.469898378775655*^9, 3.4698983962987022`*^9}, {
   3.469898762705505*^9, 3.469898799822164*^9}, 3.469899214607335*^9, 
   3.4698992556719313`*^9, {3.4698993150610847`*^9, 3.469899320032398*^9}, {
   3.469899443332966*^9, 3.469899448202669*^9}, {3.469899809660198*^9, 
   3.469899832611311*^9}, {3.469899899024125*^9, 3.4698998992362843`*^9}, {
   3.469900259231855*^9, 3.46990027815175*^9}, {3.4699003139697313`*^9, 
   3.46990037482163*^9}, {3.469902673882393*^9, 3.4699027116755133`*^9}, 
   3.469902787364902*^9, {3.469903049046687*^9, 3.4699030732220507`*^9}, {
   3.4699031615584*^9, 3.469903241283465*^9}, {3.4699047128684*^9, 
   3.4699047265740557`*^9}, {3.469904790555605*^9, 3.469904809493162*^9}, {
   3.4699049075847263`*^9, 3.4699049283862143`*^9}, {3.469970553867029*^9, 
   3.469970566105464*^9}, {3.469970597613604*^9, 3.469970647202936*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRED", "[", 
  RowBox[{"\"\<RSAFSNA\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "01", ",", "04"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
   RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<txt\>\""}], ",", 
   RowBox[{"\"\<api_key\>\"", "\[Rule]", "\"\<\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4699050559780827`*^9, 3.469905067905745*^9}, {
  3.46990529695578*^9, 3.4699052982147512`*^9}, {3.4701404875495443`*^9, 
  3.470140491370927*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293009"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294822"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338844"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335407"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345080"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "350608"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351285"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "355147"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "332791"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335615"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "343202"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "404868"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317902"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361505"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351436"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373350"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "366310"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361669"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "375078"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345547"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "348117"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "356089"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "416856"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328087"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "322747"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373626"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "358275"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "391287"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376371"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "371848"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387261"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "353159"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "367855"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376822"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "425283"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "342191"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344062"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373587"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "370144"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "399979"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "380431"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "385909"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "384798"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352554"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352479"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338788"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387964"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313593"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304056"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "334149"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "336155"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354668"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351418"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354316"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "359483"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "330411"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344797"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344966"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469972065240788*^9}]
}, Open  ]],

Cell[TextData[{
 "As an alternative to entering the API key each time, you can use ",
 StyleBox["SetOptions", "MB"],
 " to set the value during the session."
}], "Text",
 CellChangeTimes->{{3.469905082879857*^9, 3.469905111878962*^9}, 
   3.4699706617746773`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"FRED", ",", 
     RowBox[{"\"\<api_key\>\"", "\[Rule]", "\"\<\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"FRED", "[", 
  RowBox[{"\"\<RSAFSNA\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "01", ",", "04"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
   RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], "]"}]}], "Input",\

 CellChangeTimes->{{3.469905126635625*^9, 3.469905136915083*^9}, {
  3.4699052744551687`*^9, 3.46990527597438*^9}, {3.4701405057483*^9, 
  3.470140510116166*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293009.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338844.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335407.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345080.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "350608.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351285.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "355147.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "332791.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335615.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "343202.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "404868.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317902.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313552.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361505.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351436.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "366310.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361669.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "375078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345547.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "348117.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "356089.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "416856.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328087.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "322747.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373626.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "358275.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "391287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376371.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "371848.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387261.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "353159.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "367855.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "425283.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "342191.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344062.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373587.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "370144.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "399979.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "380431.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "385909.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "384798.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352554.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352479.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338788.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387964.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313593.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304056.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "334149.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "336155.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354668.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351418.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354316.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "359483.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "330411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344797.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344966.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469972066142329*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRED", "[", 
  RowBox[{"\"\<TWEXB\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"2008", ",", "01", ",", "04"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
   RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], "]"}]], "Input",\

 CellChangeTimes->{{3.4698873624329567`*^9, 3.469887391137149*^9}, {
  3.4698960077074223`*^9, 3.4698960152017*^9}, {3.469905167486741*^9, 
  3.469905168219398*^9}, {3.469905277901819*^9, 3.469905284149393*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.55`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.56`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.94`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.09`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "6", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "97.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "13", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.26`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "20", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.07`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "27", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "97.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.11`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.96`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.29`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.97`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.65`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.53`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.24`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.19`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.78`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.09`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "14", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.24`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "21", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.67`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.33`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.72`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.12`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.46`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.06`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.84`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.07`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.05`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "95.54`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "6", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "96.11`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "13", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "97.86`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "20", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "27", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "98.35`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "3", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "99.38`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "10", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "100.52`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "17", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "100.92`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "24", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "99.69`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "100.51`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.93`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "107.91`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.37`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "107.76`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "108.71`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.23`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.96`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "3", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "10", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.85`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "17", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "107.59`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "24", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "106.63`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "107.01`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "107.34`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "14", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "108.27`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "21", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.2`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.94`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.63`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "110.47`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "111.95`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "112.94`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "114.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "114.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "112.68`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.88`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "111.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.88`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.34`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.69`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "109.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "6", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "108.36`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "13", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "106.98`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "20", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "106.52`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "27", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.04`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "3", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "104.17`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "10", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.03`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "17", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.24`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "24", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.28`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "8", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.61`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "15", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "105.57`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "22", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "104.18`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "29", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.62`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "5", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "102.98`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "12", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.44`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "19", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "26", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.12`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.73`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.52`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "16", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.04`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "23", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "102.63`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "103.03`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "7", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "102.68`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "14", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.41`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "21", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.07`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.73`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "4", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "102.12`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "11", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.54`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "18", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.02`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "25", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.02`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "2", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "100.56`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "9", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "101.01`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4699720671104116`*^9}]
}, Open  ]],

Cell["\<\
The next example failed to return data for \"TWEXB\" because the unit value \
is not applicable for that series.\
\>", "Text",
 CellChangeTimes->{{3.4699051921942244`*^9, 3.469905215289448*^9}, {
  3.4699052512365913`*^9, 3.469905263586371*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRED", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<RSAFSNA\>\"", ",", "\"\<CPIAUCSL\>\"", ",", "\"\<TWEXB\>\""}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "01", ",", "04"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
   RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}], ",", 
   RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<ch1\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.469885408708943*^9, 3.469885415475775*^9}, {
   3.469887075228071*^9, 3.469887080273568*^9}, {3.46988713360455*^9, 
   3.469887134154501*^9}, 3.469887242425007*^9, {3.469887322528439*^9, 
   3.469887330856757*^9}, {3.469905178750367*^9, 3.469905179348061*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "11546.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12377.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "19737.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "20129.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "16581.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "29457.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "23260.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "28867.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "19347.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "15976.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "19135.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "17950.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "24893.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "18730.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "22661.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "16029.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "28270.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "15702.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10384.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "19931.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12756.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12502.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12887.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "11988.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10185.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "9195.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12121.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6839.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "17937.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10061.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10179.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "12183.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7612.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "19738.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "20733.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8427.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "14104.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "21315.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "39.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "11869.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8692.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4060.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "14061.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "2463.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "605.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "15376.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "38034.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "37319.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "28598.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "40006.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "39438.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "33989.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "45311.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "29013.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "31593.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "25315.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "22143.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "7682.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6178.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.3`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.4`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "6.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.8`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "2.7`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "3.9`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4.174`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4.857`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.548`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.22`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.382`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.323`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "4.638`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "3.92`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "5.582`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.233`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.866`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.437`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.921`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.503`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.319`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.077`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "8.362`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10.011`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "11.272`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "11.056`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "10.293`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "7.756`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "2.097`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "0.16`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "0.321`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "0.147`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "0.953`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "1.326`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "2.168`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "2.575`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "4.141`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "3.148`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "2.884`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", 
     RowBox[{"-", "0.504`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "3.987`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.46997206970932*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Additional processing", "Section",
 CellChangeTimes->{{3.469905353592017*^9, 3.469905356852487*^9}}],

Cell["\<\
Users may note that FRED\[RegisteredTrademark] monthly data is dated at the \
start of the month covered. It should be changed to the final day of the \
month or to the first day of the following month. To build that into the \
function a test would need to be applied to test for monthly data and then a \
replacement rule used to replace the start of the month with the end of the \
month (start of the following month). This is easier done after the data has \
been processed:\
\>", "Text",
 CellChangeTimes->{{3.469905366468796*^9, 3.469905489911618*^9}, 
   3.469905526995072*^9, {3.469970704080257*^9, 3.469970760598178*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"monthlyData", "=", 
  RowBox[{"FRED", "[", 
   RowBox[{"\"\<RSAFSNA\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"1999", ",", "01", ",", "04"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2009", ",", "12", ",", "10"}], "}"}], ",", 
    RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.469885408708943*^9, 3.469885415475775*^9}, {
   3.469887075228071*^9, 3.469887080273568*^9}, {3.46988713360455*^9, 
   3.469887134154501*^9}, 3.469887242425007*^9, {3.469887322528439*^9, 
   3.469887330856757*^9}, {3.469905178750367*^9, 3.469905179348061*^9}, {
   3.469905503885116*^9, 3.4699055142675743`*^9}, {3.4699714986256237`*^9, 
   3.469971514353126*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "218533.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "221097.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "254059.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251292.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262647.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "261477.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262600.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "265655.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "254467.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "258614.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "264717.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "318411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "236973.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251181.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "280154.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "265005.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "284306.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "281888.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "271715.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "284494.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "269667.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "271387.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "276966.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "320481.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251059.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "248078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "280749.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "275160.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "296459.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288475.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "279803.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "295561.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262645.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "292443.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288211.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "326934.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "256287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "253760.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "285773.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "285110.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "300891.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "289456.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "296145.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "308042.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "273837.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288219.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "291146.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "337470.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "268714.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "259408.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293827.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294374.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "312557.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "301279.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "310240.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294054.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304326.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "301337.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "357704.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "281463.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "282445.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "319107.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "315278.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328499.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "321151.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328025.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "326280.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313444.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "319639.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "324067.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "386918.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293009.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338844.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335407.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345080.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "350608.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351285.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "355147.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "332791.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335615.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "343202.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "404868.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317902.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313552.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361505.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351436.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "366310.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361669.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "375078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345547.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "348117.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "356089.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "416856.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328087.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "322747.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373626.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "358275.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "391287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376371.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "371848.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387261.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "353159.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "367855.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "425283.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "342191.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344062.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373587.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "370144.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "399979.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "380431.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "385909.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "384798.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352554.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352479.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338788.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387964.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313593.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304056.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "334149.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "336155.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354668.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351418.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354316.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "359483.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "330411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344797.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "1", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344966.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469972070814602*^9}]
}, Open  ]],

Cell["\<\
Applying these rules will rest the day of the month to be the end of the \
month. Note that February has to be treated differently due to leap years.\
\>", "Text",
 CellChangeTimes->{{3.469905555658454*^9, 3.469905580849431*^9}, {
   3.4699715323272953`*^9, 3.4699715331518803`*^9}, 3.469972253617364*^9, {
   3.477933798395055*^9, 3.477933831618004*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dateRules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "1", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "1", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "2", ",", "_", ",", "x__"}], "}"}], 
      "\[RuleDelayed]", 
      RowBox[{"DatePlus", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"y", ",", "3", ",", "1", ",", "x"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "3", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "3", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "4", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "4", ",", "30", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "5", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "5", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "6", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "6", ",", "30", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "7", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "7", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "8", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "8", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "9", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "9", ",", "30", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "10", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "10", ",", "31", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "11", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "11", ",", "30", ",", "x"}], "}"}]}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"y_", ",", "12", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"y", ",", "12", ",", "31", ",", "x"}], "}"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.469819700236129*^9, 3.46981970796222*^9}, {
  3.469819818478778*^9, 3.469819819860797*^9}, {3.469901003760824*^9, 
  3.4699010059412317`*^9}, {3.477933586226019*^9, 3.477933622441704*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"monthlyData", "/.", "dateRules"}]], "Input",
 CellChangeTimes->{{3.469905535497632*^9, 3.469905541904895*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "218533.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "221097.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "254059.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251292.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262647.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "261477.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262600.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "265655.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "254467.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "258614.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "264717.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1999", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "318411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "236973.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251181.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "280154.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "265005.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "284306.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "281888.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "271715.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "284494.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "269667.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "271387.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "276966.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2000", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "320481.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "251059.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "248078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "280749.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "275160.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "296459.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288475.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "279803.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "295561.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "262645.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "292443.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288211.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2001", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "326934.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "256287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "253760.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "285773.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "285110.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "300891.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "289456.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "296145.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "308042.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "273837.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "288219.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "291146.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2002", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "337470.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "268714.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "259408.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293827.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294374.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "312557.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "301279.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "310240.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294054.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304326.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "301337.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2003", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "357704.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "281463.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "282445.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "319107.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "315278.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328499.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "321151.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328025.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "326280.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313444.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "319639.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "324067.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2004", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "386918.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293009.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "294822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338844.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335407.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345080.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "350608.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351285.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "355147.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "332791.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335615.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "343202.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "404868.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317902.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313552.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361505.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351436.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "366310.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361669.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "375078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345547.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "348117.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "356089.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "416856.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328087.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "322747.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373626.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "358275.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "391287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376371.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "371848.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387261.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "353159.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "367855.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "425283.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "342191.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344062.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373587.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "370144.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "399979.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "380431.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "385909.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "384798.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352554.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352479.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338788.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387964.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313593.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "304056.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "334149.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "336155.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354668.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351418.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354316.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "359483.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "330411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344797.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344966.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.469972070992832*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making a FRED\[RegisteredTrademark] package", "Section",
 CellChangeTimes->{{3.477929231346938*^9, 3.477929241225658*^9}}],

Cell["\<\
Rather than have to return to this notebook each time you want to call some \
FRED\[RegisteredTrademark] data it is better to make a package to place in \
your StringJoin[$UserAddOnsDirectory, \"/Applications\"] directory.\
\>", "Text",
 CellChangeTimes->{{3.477929244497753*^9, 3.477929284050082*^9}, {
  3.477929378920909*^9, 3.4779294314219646`*^9}, {3.477930066303814*^9, 
  3.477930067900885*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringJoin", "[", 
  RowBox[{"$UserAddOnsDirectory", ",", "\"\</Applications\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.477929419769487*^9, 3.4779294222875566`*^9}}],

Cell[BoxData["\<\"/Users/mhoneychurch/Library/Mathematica/Applications\"\>"], \
"Output",
 CellChangeTimes->{3.477929423113772*^9, 3.477932097332192*^9, 
  3.4779321681794662`*^9, 3.477932334350088*^9, 3.477932855798455*^9, 
  3.4779337057084208`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BeginPackage", "[", "\"\<FRED`\>\"", "]"}], ";"}], "\n", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Exported", " ", "symbols", " ", "added", " ", "here", " ", "with", " ", 
    RowBox[{"SymbolName", "::", "usage"}]}], " ", "*)"}], " ", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FRED", "::", "usage"}], "=", "\"\<FRED[\!\(\*
StyleBox[\"seriesID\",
FontSlant->\"Italic\"]\), \!\(\*
StyleBox[\"startDate\",
FontSlant->\"Italic\"]\), \!\(\*
StyleBox[\"endDate\",
FontSlant->\"Italic\"]\), \!\(\*
StyleBox[\"options\",
FontSlant->\"Italic\"]\)] takes a series ID, or lists of several series ID, \
and returns the data time series. The currently supported FRED options are \
those listed here: \
http://api.stlouisfed.org/docs/fred/series_observations.html. Options should \
be entered as rules: FRED option entered as a string \[Rule] option value \
entered as a string. Start and end dates are the date range for the data \
entered as Mathematica date lists.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.477929459885755*^9, 3.47792948054613*^9}, {
   3.4779297646833572`*^9, 3.477929799521777*^9}, {3.477932564380378*^9, 
   3.4779327942745857`*^9}, 3.477934066161613*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Unprotect", "[", "FRED", "]"}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Implementation", " ", "of", " ", "the", " ", "package"}], " ", 
   "*)"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4779294837611933`*^9, 3.4779294842970533`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "FRED", ",", "makeQueryString", ",", "stringToNumber", ",", "dateRules"}],
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"the", " ", "next", " ", "two", " ", "functions", " ", 
    RowBox[{"I", "'"}], "ve", " ", "left", " ", "in", " ", "a", " ", 
    "private", " ", 
    RowBox[{"section", " ", "--"}], " ", "that", " ", "is", " ", "why", " ", 
    "they", " ", "are", " ", "colored", " ", 
    RowBox[{"differently", ".", " ", "If"}], " ", "you", " ", "want", " ", 
    "to", " ", "use", " ", "them", " ", "for", " ", "other", " ", "purposes", 
    " ", "then", " ", "add", " ", "usage", " ", "statement", " ", "above", 
    " ", "where", " ", "the", " ", "FRED", " ", "usage", " ", "statement", 
    " ", "is", " ", "and", " ", "also", " ", "Unprotect", " ", "and", " ", 
    "Protect", " ", 
    RowBox[{"them", "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"makeQueryString", "[", "rules_List", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "tmp", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tmp", "=", 
        RowBox[{"rules", "/.", 
         RowBox[{
          RowBox[{"Rule", "[", 
           RowBox[{"x_String", ",", "y_String"}], "]"}], "\[RuleDelayed]", 
          RowBox[{"StringJoin", "@@", 
           RowBox[{"List", "[", 
            RowBox[{"x", ",", "\"\<=\>\"", ",", "y"}], "]"}]}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"StringJoin", "@@", 
        RowBox[{"(", 
         RowBox[{"ToLowerCase", "/@", 
          RowBox[{"Riffle", "[", 
           RowBox[{"tmp", ",", "\"\<&\>\""}], "]"}]}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"stringToNumber", "[", "x_String", "]"}], ":=", 
    RowBox[{"ToExpression", "[", 
     RowBox[{"StringReplace", "[", 
      RowBox[{"x", ",", 
       RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dateRules", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "1", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "1", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "2", ",", "_", ",", "x__"}], "}"}], 
       "\[RuleDelayed]", 
       RowBox[{"DatePlus", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", ",", "3", ",", "1", ",", "x"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "3", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "3", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "4", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "4", ",", "30", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "5", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "5", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "6", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "6", ",", "30", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "7", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "7", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "8", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "8", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "9", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "9", ",", "30", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "10", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "10", ",", "31", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "11", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "11", ",", "30", ",", "x"}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y_", ",", "12", ",", "_", ",", "x__"}], "}"}], "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"y", ",", "12", ",", "31", ",", "x"}], "}"}]}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"main", " ", "FRED", " ", "function"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SyntaxInformation", "[", "FRED", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"\"\<ArgumentsPattern\>\"", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_", ",", "_", ",", 
        RowBox[{"OptionsPattern", "[", "]"}]}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "ideally", " ", "you", " ", "would", " ", "include", " ", "your", " ", 
    "API", " ", "key", " ", "here", " ", "as", " ", "well"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FRED", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<api_key\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<limit\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<offset\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<sort_order\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<realtime_start\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<realtime_end\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<units\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<output_type\>\"", "\[Rule]", "\"\<\>\""}], ",", 
      RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xml\>\""}], ",", 
      RowBox[{"\"\<vintage_dates\>\"", "\[Rule]", "\"\<\>\""}]}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FRED", "[", 
     RowBox[{
      RowBox[{"series", ":", 
       RowBox[{"(", 
        RowBox[{"_String", "|", "_List"}], ")"}]}], ",", "startDate_", ",", 
      "endDate_", ",", 
      RowBox[{"opts", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "today", ",", "options", ",", "start1", ",", "end1", ",", 
        "queryString", ",", "fileType", ",", "extension", ",", "tmp"}], "}"}],
       ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"today", "=", 
        RowBox[{"DateString", "[", 
         RowBox[{
          RowBox[{"DateList", "[", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
            "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"collect", " ", "options"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"options", "=", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\"\<api_key\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<api_key\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<limit\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<limit\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<offset\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<offset\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<sort_order\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<sort_order\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<realtime_start\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<realtime_start\>\"", "]"}]}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"\"\<realtime_end\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<realtime_end\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<units\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<units\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<output_type\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<output_type\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<file_type\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"\"\<vintage_dates\>\"", "\[Rule]", 
           RowBox[{"OptionValue", "[", "\"\<vintage_dates\>\"", "]"}]}]}], 
         "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"figured", " ", 
            RowBox[{"I", "'"}], "d", " ", "set", " ", "default", " ", 
            "options", " ", "to", " ", "\"\<\>\"", " ", "and", " ", "only", 
            " ", "include", " ", "non"}], "-", 
           RowBox[{
           "\"\<\>\"", " ", "in", " ", "the", " ", "query", " ", "string", 
            " ", "\[IndentingNewLine]", "options"}]}], "=", 
          RowBox[{"DeleteCases", "[", 
           RowBox[{"options", ",", 
            RowBox[{"Rule", "[", 
             RowBox[{"_", ",", "\"\<\>\""}], "]"}]}], "]"}]}], ";"}], "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"make", " ", "date", " ", "strings"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"start1", "=", 
        RowBox[{"DateString", "[", 
         RowBox[{"startDate", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
            "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"end1", "=", 
        RowBox[{"DateString", "[", 
         RowBox[{"endDate", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<Year\>\"", ",", "\"\<-\>\"", ",", "\"\<Month\>\"", ",", 
            "\"\<-\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"make", " ", "query", " ", "string", " ", "insert"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"queryString", "=", 
        RowBox[{"makeQueryString", "[", "options", "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "determine", " ", "second", " ", "argument", " ", "for", " ", 
         "Import"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"fileType", "=", 
        RowBox[{"ToLowerCase", "@", 
         RowBox[{"OptionValue", "[", "\"\<file_type\>\"", "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"extension", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{
         "fileType", ",", "\"\<xml\>\"", ",", "\"\<XML\>\"", ",", 
          "\"\<xls\>\"", ",", "\"\<*\>\"", ",", "\"\<txt\>\"", ",", 
          "\"\<*\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"tmp", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{
            RowBox[{
            "\"\<http://api.stlouisfed.org/fred/series/observations?series_id=\
\>\"", "<>", 
             RowBox[{"ToString", "[", "#", "]"}], "<>", 
             "\"\<&observation_start=\>\"", "<>", "start1", "<>", 
             "\"\<&observation_end=\>\"", "<>", "end1", "<>", "\"\<&\>\"", "<>",
              "queryString"}], ",", "extension"}], "]"}], "&"}], "/@", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", "series", "}"}], "]"}]}]}], ";", "\[IndentingNewLine]",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Switch", "[", 
         RowBox[{"fileType", ",", "\[IndentingNewLine]", "\"\<xml\>\"", ",", 
          RowBox[{"Cases", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{
             RowBox[{"XMLElement", "[", 
              RowBox[{"\"\<observation\>\"", ",", 
               RowBox[{"{", 
                RowBox[{"___", ",", 
                 RowBox[{"\"\<date\>\"", "\[Rule]", "x_"}], ",", 
                 RowBox[{"\"\<value\>\"", "\[Rule]", "y_"}]}], "}"}], ",", 
               "___"}], "]"}], "\[RuleDelayed]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"DateList", "@", "x"}], ",", 
               RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "4"}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\"\<xls\>\"", ",", 
          RowBox[{"Cases", "[", 
           RowBox[{"tmp", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", ":", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"_", "?", "NumericQ"}], ",", "_", ",", "_", ",", 
                  "__"}], "}"}]}], ",", 
               RowBox[{"y_", "?", "NumericQ"}], ",", "___"}], "}"}], 
             "\[RuleDelayed]", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}]}], ",", "\[Infinity]"}], "]"}], 
          ",", "\[IndentingNewLine]", "\"\<txt\>\"", ",", 
          RowBox[{
           RowBox[{"tmp", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"StringSplit", "[", 
               RowBox[{"#", ",", "\"\<\\t\>\""}], "]"}], "&"}], "/@", 
             RowBox[{"StringSplit", "[", 
              RowBox[{
               RowBox[{"First", "[", "tmp", "]"}], ",", "\"\<\\n\>\""}], 
              "]"}]}]}], ";", 
           RowBox[{"Cases", "[", 
            RowBox[{"tmp", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x_String", ",", 
                RowBox[{"y_String", "/;", 
                 RowBox[{"StringMatchQ", "[", 
                  RowBox[{
                   RowBox[{"StringReplace", "[", 
                    RowBox[{"y", ",", 
                    RowBox[{"\"\<,\>\"", "\[Rule]", "\"\<\>\""}]}], "]"}], 
                   ",", "NumberString"}], "]"}]}], ",", "__"}], "}"}], 
              "\[RuleDelayed]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"DateList", "@", "x"}], ",", 
                RowBox[{"stringToNumber", "@", "y"}]}], "}"}]}], ",", 
             "\[Infinity]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "/.", 
        "dateRules"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"FRED", ",", " ", "ReadProtected"}], "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.477929513885984*^9, 3.477929528359795*^9}, {
   3.4779296159090557`*^9, 3.4779296269580717`*^9}, {3.4779297188501596`*^9, 
   3.477929744311895*^9}, {3.477929864743911*^9, 3.4779298651041*^9}, {
   3.477929924626595*^9, 3.477929937947397*^9}, {3.477930250321562*^9, 
   3.477930426069173*^9}, {3.4779306707361*^9, 3.477930865361752*^9}, {
   3.477931046225081*^9, 3.477931177990138*^9}, {3.477931989065969*^9, 
   3.477932091133189*^9}, {3.477932327447431*^9, 3.477932329205628*^9}, {
   3.4779324357329493`*^9, 3.477932494252222*^9}, 3.4779326881444073`*^9, {
   3.477932817860732*^9, 3.477932829090273*^9}, {3.477933682009338*^9, 
   3.4779337004838123`*^9}, {3.477934302296105*^9, 3.477934311939793*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"End", "[", "]"}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", "FRED", "]"}], ";"}], "\n"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4779295171382437`*^9, 3.4779295177339087`*^9}}],

Cell[CellGroupData[{

Cell["test", "Subsection",
 CellChangeTimes->{{3.4779337229853277`*^9, 3.477933723647497*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"FRED", ",", 
     RowBox[{"\"\<api_key\>\"", "\[Rule]", "\"\<\!\(\*
StyleBox[\"INSERTyourFREDkey\",
FontColor->RGBColor[0., 0.5019607843137255, 0.25098039215686274`],
Background->RGBColor[0., 1., 1.]]\)\>\""}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"FRED", "[", 
  RowBox[{"\"\<RSAFSNA\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"2005", ",", "01", ",", "04"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2010", ",", "3", ",", "12"}], "}"}], ",", 
   RowBox[{"\"\<file_type\>\"", "\[Rule]", "\"\<xls\>\""}]}], "]"}]}], "Input",\

 CellChangeTimes->{{3.477934082675827*^9, 3.47793410786936*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "293009.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "294822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338844.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335407.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345080.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "350608.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351285.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "355147.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "332791.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "335615.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "343202.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2005", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "404868.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "317902.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "313552.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361505.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351436.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373350.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "366310.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "361669.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "375078.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "345547.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "348117.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "356089.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2006", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "416856.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "328087.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "322747.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373626.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "358275.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "391287.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376371.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "371848.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387261.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "353159.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "367855.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "376822.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2007", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "425283.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "342191.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "2", ",", "29", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "344062.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "373587.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "370144.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "399979.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "380431.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "385909.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "384798.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352554.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "352479.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "338788.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2008", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "387964.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "313593.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "304056.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "3", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "334149.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "4", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "336155.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "5", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354668.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "6", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "351418.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "7", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "354316.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "8", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "359483.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "9", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "330411.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "344726.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "11", ",", "30", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "347095.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2009", ",", "12", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "408925.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2010", ",", "1", ",", "31", ",", "0", ",", "0", ",", "0.`"}], 
      "}"}], ",", "321797.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2010", ",", "2", ",", "28", ",", "0", ",", "0", ",", "0"}], 
      "}"}], ",", "316673.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.477932191385614*^9, {3.477932335177635*^9, 3.477932341420869*^9}, {
   3.4779328566512012`*^9, 3.477932862017063*^9}, {3.477933706537486*^9, 
   3.477933711818204*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1212, 925},
WindowMargins->{{35, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (September 30, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 276, 7, 82, "Title"],
Cell[846, 31, 324, 8, 32, "Text"],
Cell[1173, 41, 93, 1, 32, "Text"],
Cell[1269, 44, 106, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[1400, 49, 97, 1, 89, "Section"],
Cell[1500, 52, 1818, 37, 147, "Text"],
Cell[3321, 91, 703, 16, 100, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4061, 112, 162, 2, 89, "Section"],
Cell[4226, 116, 701, 11, 71, "Text"],
Cell[CellGroupData[{
Cell[4952, 131, 655, 13, 66, "Input"],
Cell[5610, 146, 6323, 151, 313, "Output"]
}, Open  ]],
Cell[11948, 300, 256, 5, 40, "Text"],
Cell[12207, 307, 413, 9, 106, "Input"],
Cell[CellGroupData[{
Cell[12645, 320, 701, 15, 106, "Input"],
Cell[13349, 337, 6321, 151, 391, "Output"]
}, Open  ]],
Cell[19685, 491, 136, 1, 40, "Text"],
Cell[19824, 494, 741, 15, 106, "Input"],
Cell[20568, 511, 184, 4, 40, "Text"],
Cell[CellGroupData[{
Cell[20777, 519, 300, 8, 57, "Input"],
Cell[21080, 529, 6321, 151, 391, "Output"]
}, Open  ]],
Cell[27416, 683, 242, 5, 41, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27695, 693, 207, 4, 111, "Section"],
Cell[CellGroupData[{
Cell[27927, 701, 251, 7, 52, "Subsection"],
Cell[28181, 710, 349, 11, 40, "Text"],
Cell[28533, 723, 1702, 40, 225, "Input"],
Cell[CellGroupData[{
Cell[30260, 767, 512, 12, 57, "Input"],
Cell[30775, 781, 6323, 151, 391, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37147, 938, 128, 1, 52, "Subsection"],
Cell[37278, 941, 428, 10, 40, "Text"],
Cell[37709, 953, 1886, 47, 226, "Input"],
Cell[CellGroupData[{
Cell[39620, 1004, 441, 12, 57, "Input"],
Cell[40064, 1018, 6630, 161, 391, "Output"]
}, Open  ]],
Cell[46709, 1182, 182, 2, 40, "Text"],
Cell[CellGroupData[{
Cell[46916, 1188, 506, 14, 57, "Input"],
Cell[47425, 1204, 7030, 174, 391, "Output"]
}, Open  ]],
Cell[54470, 1381, 134, 1, 40, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54641, 1387, 238, 3, 52, "Subsection"],
Cell[54882, 1392, 773, 15, 65, "Text"],
Cell[CellGroupData[{
Cell[55680, 1411, 4439, 113, 547, "Input"],
Cell[60122, 1526, 2757, 57, 421, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[62913, 1588, 4098, 108, 547, "Input"],
Cell[67014, 1698, 2417, 51, 236, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[69465, 1754, 4018, 101, 472, "Input"],
Cell[73486, 1857, 2166, 47, 196, "Output"]
}, {2}]],
Cell[75664, 1907, 682, 12, 88, "Text"],
Cell[76349, 1921, 309, 6, 57, "Input",
 Evaluatable->False],
Cell[76661, 1929, 181, 2, 40, "Text"],
Cell[76845, 1933, 159, 2, 57, "Input",
 Evaluatable->False],
Cell[77007, 1937, 410, 7, 63, "Text"],
Cell[77420, 1946, 427, 10, 57, "Input"],
Cell[CellGroupData[{
Cell[77872, 1960, 423, 10, 57, "Input"],
Cell[78298, 1972, 187, 4, 57, "Output"]
}, Open  ]],
Cell[78500, 1979, 267, 8, 40, "Text"],
Cell[CellGroupData[{
Cell[78792, 1991, 92, 2, 57, "Input"],
Cell[78887, 1995, 221, 4, 57, "Output"]
}, Open  ]],
Cell[79123, 2002, 413, 10, 40, "Text"],
Cell[CellGroupData[{
Cell[79561, 2016, 337, 7, 57, "Input"],
Cell[79901, 2025, 221, 4, 57, "Output"]
}, Open  ]],
Cell[80137, 2032, 259, 5, 40, "Text"],
Cell[80399, 2039, 943, 24, 130, "Input"],
Cell[CellGroupData[{
Cell[81367, 2067, 143, 2, 57, "Input"],
Cell[81513, 2071, 114, 1, 57, "Output"]
}, Open  ]],
Cell[81642, 2075, 346, 9, 41, "Text"],
Cell[81991, 2086, 338, 9, 57, "Input"],
Cell[82332, 2097, 508, 12, 40, "Text"],
Cell[82843, 2111, 2013, 50, 226, "Input"],
Cell[84859, 2163, 1895, 44, 163, "Text"],
Cell[86757, 2209, 6389, 128, 606, "Input"],
Cell[93149, 2339, 200, 4, 41, "Text"],
Cell[CellGroupData[{
Cell[93374, 2347, 687, 15, 57, "Input"],
Cell[94064, 2364, 6628, 161, 391, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100729, 2530, 463, 12, 57, "Input"],
Cell[101195, 2544, 1761, 29, 795, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102993, 2578, 466, 12, 57, "Input"],
Cell[103462, 2592, 7073, 174, 391, "Output"]
}, Open  ]],
Cell[110550, 2769, 243, 5, 40, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110842, 2780, 130, 1, 111, "Section"],
Cell[CellGroupData[{
Cell[110997, 2785, 261, 3, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[111283, 2792, 1224, 23, 82, "Input"],
Cell[112510, 2817, 6628, 161, 391, "Output"]
}, Open  ]],
Cell[119153, 2981, 395, 9, 40, "Text"],
Cell[CellGroupData[{
Cell[119573, 2994, 585, 14, 82, "Input"],
Cell[120161, 3010, 5603, 138, 391, "Output"]
}, Open  ]],
Cell[125779, 3151, 156, 3, 40, "Text"],
Cell[CellGroupData[{
Cell[125960, 3158, 739, 19, 82, "Input"],
Cell[126702, 3179, 5377, 120, 320, "Output"]
}, Open  ]],
Cell[132094, 3302, 714, 19, 88, "Text"],
Cell[132811, 3323, 276, 8, 57, "Input"],
Cell[CellGroupData[{
Cell[133112, 3335, 851, 22, 82, "Input"],
Cell[133966, 3359, 8555, 246, 415, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[142570, 3611, 177, 4, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[142772, 3619, 1347, 25, 82, "Input"],
Cell[144122, 3646, 22585, 587, 1151, "Output"]
}, Open  ]],
Cell[166722, 4236, 295, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[167042, 4246, 1014, 24, 82, "Input"],
Cell[168059, 4272, 8428, 241, 415, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[176536, 4519, 161, 2, 37, "Subsubsection"],
Cell[CellGroupData[{
Cell[176722, 4525, 1150, 22, 82, "Input"],
Cell[177875, 4549, 3367, 50, 1673, "Output"]
}, Open  ]],
Cell[181257, 4602, 281, 5, 40, "Text"],
Cell[CellGroupData[{
Cell[181563, 4611, 614, 15, 82, "Input"],
Cell[182180, 4628, 11777, 246, 985, "Output"]
}, Open  ]],
Cell[193972, 4877, 530, 9, 87, "Text"],
Cell[CellGroupData[{
Cell[194527, 4890, 1036, 25, 106, "Input"],
Cell[195566, 4917, 8554, 246, 415, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[204181, 5170, 124, 1, 111, "Section"],
Cell[204308, 5173, 458, 12, 65, "Text"],
Cell[204769, 5187, 9357, 199, 843, "Input"],
Cell[214129, 5388, 398, 8, 65, "Text"],
Cell[214530, 5398, 9867, 212, 938, "Input"],
Cell[CellGroupData[{
Cell[224422, 5614, 669, 14, 57, "Input"],
Cell[225094, 5630, 10080, 298, 510, "Output"]
}, Open  ]],
Cell[235189, 5931, 263, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[235477, 5941, 809, 20, 106, "Input"],
Cell[236289, 5963, 10198, 298, 510, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246524, 6266, 510, 11, 57, "Input"],
Cell[247037, 6279, 17311, 508, 842, "Output"]
}, Open  ]],
Cell[264363, 6790, 255, 5, 40, "Text"],
Cell[CellGroupData[{
Cell[264643, 6799, 738, 16, 57, "Input"],
Cell[265384, 6817, 20605, 619, 937, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[286038, 7442, 106, 1, 111, "Section"],
Cell[286147, 7445, 641, 10, 88, "Text"],
Cell[CellGroupData[{
Cell[286813, 7459, 728, 15, 57, "Input"],
Cell[287544, 7476, 22528, 658, 1080, "Output"]
}, Open  ]],
Cell[310087, 8137, 365, 6, 40, "Text"],
Cell[310455, 8145, 2855, 74, 153, "Input"],
Cell[CellGroupData[{
Cell[313335, 8223, 134, 2, 57, "Input"],
Cell[313472, 8227, 22659, 658, 1080, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[336180, 8891, 128, 1, 111, "Section"],
Cell[336311, 8894, 412, 7, 65, "Text"],
Cell[CellGroupData[{
Cell[336748, 8905, 196, 4, 57, "Input"],
Cell[336947, 8911, 251, 4, 57, "Output"]
}, Open  ]],
Cell[337213, 8918, 1274, 29, 272, "Input",
 InitializationCell->True],
Cell[338490, 8949, 406, 11, 130, "Input",
 InitializationCell->True],
Cell[338899, 8962, 16174, 375, 1865, "Input",
 InitializationCell->True],
Cell[355076, 9339, 315, 9, 153, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[355416, 9352, 94, 1, 52, "Subsection"],
Cell[CellGroupData[{
Cell[355535, 9357, 710, 18, 106, "Input"],
Cell[356248, 9377, 10913, 316, 533, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
